******************************************************************
**  Country: Ethiopia                                           **
**                                                              **
**  Description: Creates variables for empirical analysis       **
**                                                              **
**  Program first written: January 2022 (Valentina Costa) 		**
**  Program last revised:  September 2023                   	** 
******************************************************************
	
******************************************************************
*** SET OF VARIABLES ***
******************************************************************
* 1. Family characteristics (Ethiopia ESS 2018-19)
* 2. Personal characteristics of the youth (High Frequency Phone Survey 2020-2023)
* 3. Community characteristics (High Frequency Phone Survey 2020-2023)
* 4. Youths Aspirations (High Frequency Phone Survey 2020-2023)
* 5. Remittances (High Frequency Phone Survey 2020-2023)
* 6. Consumption aggregates (Ethiopia ESS 2018-19)

clear
set more off
capture set max_memory 500M 
capture set mem 500M		

cap log close


************************* 1. Family characteristics ****************************
// Ethiopia ESS 2018-19 //

	use "$ethiopia_f2f\sect_cover_hh_w4.dta", clear
	merge 1:m household_id using "$ethiopia_f2f\sect1_hh_w4.dta"
	drop _m
	merge 1:1 individual_id household_id using "$ethiopia_f2f\sect2_hh_w4.dta"
	drop _m
	merge 1:1 individual_id household_id using "$ethiopia_f2f\sect4_hh_w4.dta"
	drop _m
	drop if s1q05==2 // not HH member anymore
	
	gen female =(s1q02==2)
	gen head=(s1q01==1)
	rename saq09 hhsize
	rename s1q03a age
	gen youth=(age<26)
	gen youth_head=(head==1) if youth==1  	// 4% of the youths are head of the HH
	gen adult_head=(head==1) if youth==0  	// 58% of the adults are head of the HH
	gen head_age=(youth==0) if head==1  	// 89% of the head of the HH are adults
	 
	gen dependent=1 if age<15 | age>=65
	gen independent=1 if age>=15 & age<65
	
	
	*1.1. Education of adult head of HH (not youth) * 
	* Highest level of education
	gen edu_lvl_f2f=1 if (s2q04==2 | s2q06==0 | inrange(s2q06,1,5) | inlist(s2q06,96,98,99)) 
	replace edu_lvl_f2f=2 if (inrange(s2q06,6,11) | s2q06==93) | (inrange(s2q06,21,23)) 
	replace edu_lvl_f2f=3 if (s2q06==12 | inrange(s2q06,24,30) | inrange(s2q06,31,33) | inlist(s2q06,94,95)) 
	replace edu_lvl_f2f=4 if (inrange(s2q06,13,20) | inlist(s2q06,34,35))
	lab define edu_lvl_f2f 1 "None" 2 "Primary" 3 "Secondary" 4 "Tertiary"
	
	gen edulvl_adult_f2f=edu_lvl_f2f if adult_head==1
	gen edulvl_youth_f2f=edu_lvl_f2f if youth_head==1
	
	* Years of education // to verify 
	gen edu_yrs_f2f=0 if s2q04==2 | s2q06==0 | inlist(s2q06,93,95,96,98,99)	
	replace edu_yrs_f2f=1 if s2q06==1 
	replace edu_yrs_f2f=2 if s2q06==2
	replace edu_yrs_f2f=3 if s2q06==3
	replace edu_yrs_f2f=4 if s2q06==4
	replace edu_yrs_f2f=5 if s2q06==5	
	replace edu_yrs_f2f=6 if s2q06==6
	replace edu_yrs_f2f=7 if s2q06==7	
	replace edu_yrs_f2f=8 if s2q06==8
	replace edu_yrs_f2f=9 if s2q06==9   | s2q06==21
	replace edu_yrs_f2f=10 if s2q06==10 | s2q06==22
	replace edu_yrs_f2f=11 if s2q06==11 | s2q06==23 | s2q06==25
	replace edu_yrs_f2f=12 if inlist(s2q06,12,24,26,27) 
	replace edu_yrs_f2f=13 if s2q06==13 | s2q06==14 | s2q06==28 | s2q06==29 | s2q06==30
	replace edu_yrs_f2f=14 if s2q06==15 | s2q06==19 | s2q06==31  
	replace edu_yrs_f2f=15 if s2q06==16  | s2q06==32
	replace edu_yrs_f2f=16 if s2q06==17
	replace edu_yrs_f2f=17 if s2q06==18 | s2q06==33
	replace edu_yrs_f2f=18 if s2q06==20 | s2q06==34 
	replace edu_yrs_f2f=19 if s2q06==35
	
	gen eduyrs_adult_f2f=edu_yrs_f2f if adult_head==1
	gen eduyrs_youth_f2f=edu_yrs_f2f if youth_head==1
	
	/* Categorical years of education 
	gen education=0 if s2q04==2 | s2q06==0 | inlist(s2q06,93,95,96,98,99)
	replace education=8 if inrange(s2q06,1,8)  | s2q06==21
	replace education=14 if inrange(s2q06,9,17) | inlist(s2q06,22,23,25) | inrange(s2q06,28,33)  
	replace education=18 if inrange(s2q06,18,20) | s2q06==34 | s2q06==35 */
	
	
	*1.2. Occupation of adult head of HH (not youth)*
	* Wage work
	*drop if s4q12==. & s4q00==1 	// 2 missing obs
	gen wage_work_f2f_curr2=(s4q12==1) 								 							// current wage work
	gen wage_work_f2f2_abs2=(s4q17==1 & s4q18!=2 & s4q21==2)		 							// temporary absence (<3 months)
	gen wage_work_f2f2_122=(s4q33b==1) 															// last 12-months wage work
	gen wage_work_f2f_7days2=(wage_work_f2f_curr + wage_work_f2f2_abs >0) 						// last 7days wage work
	
	gen wage_work_f2f=(wage_work_f2f_7days==1 | wage_work_f2f2_12==1) & adult_head==1    		// total wage workers
	gen stem_f2f=(wage_work_f2f==1) & (inlist(s4q34d,14)) & adult_head==1  						// stem jobs
	
	* Ag work
	gen ag_work_f2f_curr=(s4q05==1) & (inlist(s4q07,1,2)) 				 						// current ag work
	gen ag_work_f2f_abs=(s4q17==1 & s4q18==2 & s4q21==1) & (inlist(s4q22,1,2)) 					// temporary absence (<3 months)
	
	gen ag_work_f2f=(ag_work_f2f_curr + ag_work_f2f_abs>0) & adult_head==1						// total ag work

	* Own account work
	gen own_work_f2f=(s4q08==1) & adult_head==1													// current work
	
	
// collapsing all vrbs at hh level //
collapse (max)  pw_w4 adult_head youth_head hhsize edu_lvl_f2f edulvl_adult_f2f edulvl_youth_f2f wage_work_f2f stem_f2f ag_work_f2f own_work_f2f (median) eduyrs_youth_f2f eduyrs_adult_f2f edu_yrs_f2f (sum) dependent independent, by(household_id ea_id)

	replace independent=1 if (independent==0 & dependent>0)
	gen	dependency_ratio = dependent/independent 
	tab dependency_ratio, m
	
	count if (independent==0 & dependent==0) | (independent==0 & dependent>0) // >> missing values
	count if (independent>0 & dependent==0) // >> 0

	replace edulvl_adult_f2f=edulvl_youth_f2f if edulvl_adult_f2f==. & youth_head==1 
	replace edulvl_adult_f2f=1 if edulvl_adult_f2f==. & adult_head==1
	replace edu_lvl_f2f=1 if edu_lvl_f2f==. & adult_head==1

	replace eduyrs_adult_f2f=eduyrs_youth_f2f if eduyrs_adult_f2f==. & youth_head==1 
	replace eduyrs_adult_f2f=1 if eduyrs_adult_f2f==. & adult_head==1
	replace edu_yrs_f2f=1 if edu_yrs_f2f==. & adult_head==1
	drop edulvl_youth_f2f eduyrs_youth_f2f dependent independent adult_head
	
	rename pw_w4 weights
	
	isid household_id
	
tempfile all_f2f
save `all_f2f', replace 

	

***************** 2. Personal characteristics of the youth *********************
// High Frequency Phone Survey 2020-2023 //

use "$ethiopia_youth\r12_wb_lsms_hfpm_hh_survey_public_microdata.dta", clear
numlabel, add
	gen individual_id=substr(ii4_resp_id,-1,1)	
	destring individual_id, replace
merge 1:1 household_id individual_id using "$ethiopia_youth\wb_lsms_hfpm_hh_survey_roster_round12_clean_public.dta"

	gen youth_head2=(bi6_hhm_relhhh==1) & ii4_resp_age<26 // 74 obs (8.4% of the youths are the head of HH)
	recode youth_head2 (.=0)

	* The oldest / youngest youth *
	bysort household_id: egen oldest=max(ii4_resp_age) if ii4_resp_age>=15 & ii4_resp_age<=25
	bysort household_id: egen youngest=min(ii4_resp_age) if ii4_resp_age>=15 & ii4_resp_age<=25
	drop if _m==2 
	drop _merge
	
	* 2.1. Sex*
	gen female=(ii4_resp_gender==2)

	* 2.2. Age*
	keep if inrange(ii4_resp_age,15,25) //keep only youth - 881 observations
	rename ii4_resp_age age
	gen age_group=.
	replace age_group=1 if inrange(age,15,18)
	replace age_group=2 if inrange(age,19,22)
	replace age_group=3 if inrange(age,23,25)
	gen age_group1518=(age_group==1) 
	gen age_group1922=(age_group==2) 
	gen age_group2325=(age_group==3) 
	
	* 2.3. Education of the head of HH *
	* Highest levels of education *
	gen edu_youth=1 if (ya2_sch_attend==0 | ya8_sch_qual==0)
	replace edu_youth=2 if (ya8_sch_qual==1)
	replace edu_youth=3 if (ya8_sch_qual==2) 
	replace edu_youth=4 if ya8_sch_qual==3 | ya8_sch_qual==4
	replace edu_youth=5 if ya8_sch_qual==5
	gen none=(edu_youth==1) 
	gen primary=(edu_youth==2)
	gen secondary=(edu_youth==3)
	gen tertiary=(edu_youth==4)
	gen university=(edu_youth==5)

	* Education (years)*
	gen edu_youth_yrs=0 if (ya2_sch_attend==0 | ya11_sch_attend_cur_level==0) | inlist(ya11_sch_attend_cur_level,93,95,96,98,99)	
	replace edu_youth_yrs=1 if ya11_sch_attend_cur_level==1 
	replace edu_youth_yrs=2 if ya11_sch_attend_cur_level==4
	replace edu_youth_yrs=3 if ya11_sch_attend_cur_level==5
	replace edu_youth_yrs=4 if ya11_sch_attend_cur_level==6
	replace edu_youth_yrs=5 if ya11_sch_attend_cur_level==7	
	replace edu_youth_yrs=6 if ya11_sch_attend_cur_level==8
	replace edu_youth_yrs=7 if ya11_sch_attend_cur_level==9	
	replace edu_youth_yrs=8 if ya11_sch_attend_cur_level==10
	replace edu_youth_yrs=9 if ya11_sch_attend_cur_level==16   
	replace edu_youth_yrs=10 if ya11_sch_attend_cur_level==17 
	replace edu_youth_yrs=11 if ya11_sch_attend_cur_level==20 
	replace edu_youth_yrs=12 if ya11_sch_attend_cur_level==21 
	replace edu_youth_yrs=15 if (ya11_sch_attend_cur_level==19  | ya11_sch_attend_cur_level_other=="Diploma")
	replace edu_youth_yrs=19 if (ya11_sch_attend_cur_level==22  | ya11_sch_attend_cur_level_other=="College")

	replace edu_youth_yrs=0 if ya8_sch_qual==0 & ya10_sch_attend_cur==0 
	replace edu_youth_yrs=8 if ya8_sch_qual==1 & ya10_sch_attend_cur==0 
	replace edu_youth_yrs=12 if ya8_sch_qual==2 & ya10_sch_attend_cur==0 
	replace edu_youth_yrs=15 if ya8_sch_qual==3 & ya10_sch_attend_cur==0 
	replace edu_youth_yrs=19 if (ya8_sch_qual==4 | ya8_sch_qual==5) & ya10_sch_attend_cur==0 
	
	/*Categorical years of education 
	gen education=0 if ya8_sch_qual==0 | ya2_sch_attend==0
	replace education=8 if ya8_sch_qual==1 
	replace education=14 if ya8_sch_qual==2 
	replace education=18 if ya8_sch_qual==3 | ya8_sch_qual==4 | ya8_sch_qual==5*/
	
	* 2.4. Ideal job characteristic: Interesting job to do*
	gen interest_chr =(ya25_job_char_1==1 & ya25_job_char_2!=1) | (ya25_job_char_1==1 & ya25_job_char_2==1) | (ya25_job_char_1!=1 & ya25_job_char_2==1)
	
	* 2.5. Ideal job characteristic: Well paid job*
	gen remunerative =(ya25_job_char_1==3 & ya25_job_char_2!=3) | (ya25_job_char_1==3 & ya25_job_char_2==3) | (ya25_job_char_1!=3 & ya25_job_char_2==3)	
	
	* 2.6. Main influencing factor: Youth interest in the tasks*
	gen interest_fct =(ya26_job_factor==3) 
	
	* 2.7. Likelihood to achieve the dream job (self-efficacy)* 
	gen likelihood=(ya28_job_likely) if ya27_job_cur==0
	replace likelihood=6 if likelihood==.
	
	* 2.8. Constraint to achieve the dream job: Lack of money*
	gen lack_money =(ya29_job_constr_1==1 & ya29_job_constr_2!=1) | (ya29_job_constr_1==1 & ya29_job_constr_2==1) | (ya29_job_constr_1!=1 & ya29_job_constr_2==1)
	
	* 2.9. Constraint to achieve the dream job: Domestic obligation **and pregnancy*
	gen domestic_work =((ya29_job_constr_1==8 & ya29_job_constr_2!=8) | (ya29_job_constr_1==8 & ya29_job_constr_2==8) | (ya29_job_constr_1!=8 & ya29_job_constr_2==8)) 
	//| ((ya29_job_constr_1==10 & ya29_job_constr_2!=10) | (ya29_job_constr_1==10 & ya29_job_constr_2==10) | (ya29_job_constr_1!=10 & ya29_job_constr_2==10))
	
	* 2.10. Ideal levl of education: university*
	gen ideal_uni=(ya22_edu_imagine==4)
	
	* 2.11. Ideal levl of education: post-graduate*
	gen ideal_postgrad=(ya22_edu_imagine==5)
	
	* 2.12. Currently doing ideal job*
	gen ideal_job=(ya27_job_cur==1)
	
	* 2.13. Currently doing a paid job*
	gen paid_job=(ya4_activity_cur==1 | ya14_activity_cur==1)
	
	* 2.14. Currently agriculture worker*
	gen ag_job=(ya4_activity_cur==2 | ya14_activity_cur==2)
	
	* 2.15. Currently attending school *
	gen training=(ya14_activity_cur==3)
	replace training=1 if ya14_activity_cur==3
	gen attending_schoolt=ya10_sch_attend_cur
	recode attending_schoolt (.=0)
	replace attending_schoolt=1 if training==1
	
	* 2.16. Currently working (either paid job or farming) *
	gen working=(paid_job==1 | ag_job==1 ) 
	gen ideal_job_curr=(ya27_job_cur==1 & working==1)
	
	* 2.17. NEET *
	gen neitherw_s=(working==0 & attending_schoolt==0)
	
	* 2.18. Age start working *
	replace ya6_work_age=. if ya6_work_age==-98 | ya6_work_age==-99
	replace ya16_work_age=. if ya16_work_age==-98 | ya16_work_age==-99
	gen age_working=ya6_work_age 
	replace age_working=ya16_work_age if ya6_work_age==. 
	
	gen working_child14=(age_working<15) 
	gen working_youth1518=(age_working>=15 & age_working<19) 
	gen working_youth1922=(age_working>=19 & age_working<23)  
	gen working_youth2325=(age_working>=23 & age_working<=25) 
	replace age_working=. if age_working>25 



*************************** 3. Community characteristics ***********************	
	* 3.1. Ideal job characteristic: Job that family and friends regard highly*
	gen status_chr =(ya25_job_char_1==2 & ya25_job_char_2!=2) | (ya25_job_char_1==2 & ya25_job_char_2==2) | (ya25_job_char_1!=2 & ya25_job_char_2==2)	
	
	* 3.2. Main influencing factor: Family and friends*
	gen status_fct =(ya26_job_factor==1) 
	
	* 3.3. Sector (urban)* 
	gen urban=(cs4_sector==2)
	
	* 3.4. Any other woman doing his/her dream job (Role Model)*
	gen role_model_w=(ya31_job_com_f==1)
	
	* 3.5. Anyone doing his/her dream job (Role Model)*
	gen role_model=(ya30_job_com==1) 
	

	
*************************** 4. Youths Aspirations ******************************
*Dummies: ideal job is... 
gen stem_job=(inlist(ya24_job_30yrs_code,5,11,14,31,41))
	gen stem_exp=likelihood if stem_job==1
	replace stem_exp=0 if likelihood<=2
	replace stem_exp=1 if likelihood>2
	rename likelihood expectation
	gen likely= inlist(expectation,4,5,6)

*Dummies: ideal education is...
gen ideal_uniabove=(ideal_uni==1 | ideal_postgrad==1) 
	* Educational gap *
	gen curr_uniabove=.
	replace curr_uniabove=0 if edu_youth<=3
	replace curr_uniabove=1 if edu_youth>3
	gen edu_aspgap=ideal_uniabove-curr_uniabove // Ray (2006) definition
	tab edu_aspgap
	recode edu_aspgap (-1=0)
	
*Dummy: considering leaving the community to look for better job opportunities
gen migration=(ya36_leave==1)

* Any someone doing his/her dream job (Role Model)*
gen role_model_stem=(ya30_job_com==1) if stem_job==1
replace role_model_stem=0 if role_model_stem==. 


egen hhid= group(cs1_region cs2_zoneid cs3_woredaid cs3c_subcityid cs3b_kebeleid cs5_eaid cs6_hhid)

tab ya37_leave_where, gen(s5eq37__)

// collapsing all vrbs at hh level //
collapse (max) youth_head2 stem_job ideal_uniabove migration female age_group age_group1518 age_group1922 age_group2325 none primary secondary tertiary university attending_schoolt working ideal_job_curr paid_job ag_job  neitherw_s working_child14 working_youth1518 working_youth1922 working_youth2325 urban interest_chr role_model status_chr oldest edu_youth edu_aspgap likely lack_money s5eq37__1 s5eq37__2 s5eq37__3 s5eq37__4 s5eq37__5 (median) age edu_youth_yrs age_working, by(household_id ea_id)

isid household_id
	
tempfile all_youth
save `all_youth', replace
	

********************************* 5.Remittances ********************************
	use "$ethiopia_youth\r1_wb_lsms_hfpm_hh_survey_public_microdata.dta", clear
	numlabel, add
	rename ii4_resp_id individual_id

	rename lc1_rem_for remittance1
	replace remittance1=0 if remittance1==-98
	rename lc1_rem_dom remittance2
	tab1 remittance1 remittance2
	
	collapse (max) remittance1 remittance2, by(household_id ea_id) 
	
	isid household_id

	tempfile remittences
	save `remittences', replace
	
	use "$ethiopia_youth\r1_wb_lsms_hfpm_hh_survey_public_microdata.dta", clear
	numlabel, add
	rename lc1_rem_for remittance1_EA
	replace remittance1_EA=0 if remittance1_EA==-98
	rename lc1_rem_dom remittance2_EA
	tab1 remittance1_EA remittance2_EA
	
	collapse (max) remittance1_EA remittance2_EA, by(ea_id) 
	
	isid ea_id

	tempfile remittences_ea
	save `remittences_ea', replace


************************** 6. Consumption aggregates ***************************
	use  "$ethiopia_f2f\cons_agg_w4.dta", clear

	gen cons_quint1=(cons_quint==1)
	gen cons_quint2=(cons_quint==2)
	gen cons_quint3=(cons_quint==3)
	gen cons_quint4=(cons_quint==4)
	gen cons_quint5=(cons_quint==5)
	
	keep household_id ea_id pw_w4 cons_quint cons_quint1 cons_quint2 cons_quint3 cons_quint4 cons_quint5
	rename pw_w4 weights 
	
	isid household_id
	
tempfile cons_f2f
save `cons_f2f', replace 

	  
******************************** merging datasets ******************************		
use `all_f2f'
merge 1:1 household_id using `all_youth'
keep if _m==3
drop _merge
merge 1:1 household_id using `remittences'
keep if _m==3
drop _merge
merge 1:1 household_id using `cons_f2f'
keep if _m==3
drop _merge
merge m:1 ea_id using `remittences_ea'
keep if _m==3
drop _merge

rename household_id y4_hhid
gen country=1

* 8% of the youth are head of the HH *
count if youth_head==1 & youth_head2==1 // 72 youth head of HH in the phone survey were also youth head of HH in the f-2-f
count if youth_head!=1 & youth_head2==1 // 2 youth head of HH in the phone survey were not youth head of HH in the f-2-f

drop youth_head 

* Labelling variables *
lab var country "country"
lab var weights "HH weights"
lab var ea_id "EA ID"
lab var y4_hhid "HH ID"
lab var youth_head2 "Youth head of the HH"
lab var urban "Sector is Urban"
lab var hhsize "Size of the HH - F2F"
lab var dependency_ratio "Dependency ratio - F2F"
lab var edu_lvl_f2f "Highest level of education of HH members - F2F"
lab var edulvl_adult_f2f "Highest level of education of adult head of HH - F2F"
lab var edu_yrs_f2f "Average education of HH members - F2F"
lab var eduyrs_adult_f2f "Average education of adult head of HH - F2F"
lab var wage_work_f2f "Head of HH working in wage job- F2F"
lab var stem_f2f "Head of HH working in STEM related jobs - F2F"
lab var ag_work_f2f "Head of HH working in agriculture - F2F"
lab var own_work_f2f "Head of HH is own account worker - F2F"
lab var cons_quint "Consumption quintile – F2F"
lab var cons_quint1 "1st Consumption quintile (poorest)"
lab var cons_quint2 "2nd Consumption quintile"
lab var cons_quint3 "3rd Consumption quintile"
lab var cons_quint4 "4th Consumption quintile"
lab var cons_quint5 "5th Consumption quintile (richest)"
lab var female "Youth is female"
lab var age_group "Youth age group (full sample, 15-25)"
lab var age_group1518 "15-18 years old"
lab var age_group1922 "19-22 years old"
lab var age_group2325 "23-25 years old"
lab var oldest "The oldest youth"
lab var age_working "Youth age start working (full sample, 15-25)"
lab var edu_youth "Youth education (highest levels of education)"
lab var edu_youth_yrs "Youth education (years of education)"
lab var paid_job "Youth currently doing a paid job"
lab var ag_job "Youth currently agriculture worker"
lab var working "Youth currently working (either paid job or farming)"
lab var attending_schoolt "Youth currently attending school"
lab var neitherw_s "Youth currently neither working or attending school"
lab var ideal_job_curr "Youth currently doing the ideal job"
lab var interest_chr "Ideal job characteristic: Interesting job to do"
lab var status_chr "Ideal job characteristic: Job that family and friends regard highly"
lab var lack_money "Ideal job constraint: Lack of money"
lab var likely "Youth likelihood to reach the dream job"
lab var role_model "Youth knows someone in the community that has your dream job"
lab var stem_job "Ideal job: STEM related work"
lab var migration "Youth is considering leaving the community to look for better job opportunities"
lab var s5eq37__1 "Moving to capital city"
lab var s5eq37__2 "Moving to a town/city"
lab var s5eq37__3 "Moving to rural area"
lab var s5eq37__4 "Moving to another country"
lab var s5eq37__5 "Moving to - no preference"
label var working_child14 "Started working below 14 years old"
label var working_youth1518 "Started working between 15 and 18 years old"
label var working_youth1922 "Started working between 19 and 22 years old"
label var working_youth2325 "Started working between 23 and 25 years old"
lab define edu_youth 1 "None" 2 "Primary" 3 "Secondary" 4 "Tertiary" 5 "University"
label var edu_aspgap "Educational gap"
label var none "No degree"
label var primary "Primary"
label var secondary "Secondary"
label var tertiary "Tertiary"
label var university "University"
label var ideal_uniabove "Ideal level of education: university and above"
lab var remittance1 "HHs with remittances from abroad"
lab var remittance2 "HHs with remittances from family within the country"
label var remittance1_EA "HHs with remittances from abroad within EA"
label var remittance2_EA "HHs with remittances from family within EA"
label var age "Age (in years)"

isid y4_hhid

// Saving the final dataset for analysis //
save "$ethiopia_final\ethiopia.dta", replace

clear
capture log close