******************************************************************
**  Country: Malawi		                                        **
**                                                              **
**  Description: Creates variables for empirical analysis       **
**                                                              **
**  Program first written: January 	2022 (Valentina Costa) 		**
**  Program last revised:  September 2023                  	 	** 
******************************************************************
******************************************************************
*** SET OF VARIABLES ***
******************************************************************
* 1. Family characteristics (Integrated Household Panel Survey 2010-2013-2016-2019)
* 2. Personal characteristics of the youth (High Frequency Phone Survey 2020-2023)
* 3. Community characteristics (High Frequency Phone Survey 2020-2023)
* 4. Youths Aspirations (High Frequency Phone Survey 2020-2023)
* 5. Remittances (High Frequency Phone Survey 2020-2023)
* 6. Consumption aggregates (Integrated Household Panel Survey 2010-2013)


clear
set more off
capture set max_memory 500M 
capture set mem 500M		

cap log close


************************* 1. Family characteristics ****************************
// Integrated Household Panel Survey 2010-2019 //
	use "$malawi_f2f_19\hh_mod_a_filt_19.dta", clear
	merge 1:m y4_hhid using "$malawi_f2f_19\hh_mod_b_19.dta"
	drop _m
	merge 1:1 y4_hhid id_code using "$malawi_f2f_19\hh_mod_c_19.dta"
	drop _m
	merge 1:1 y4_hhid id_code using "$malawi_f2f_19\hh_mod_e_19.dta"
	drop _merge

	gen female =(hh_b03==2)
	gen head=(hh_b04==1)
	rename hh_b05a age
	gene youth=(age<26)
	gen youth_head=(head==1) & youth==1 	// 3% of the youths are head of the HH
	gen adult_head=(head==1) & youth==0 	// 19% of the adults are head of the HH
	gen head_age=(youth==0) if head==1  	// 87% of the head of the HH are adults

	gen dependent=1 if age<15 | age>=65
	gen independent=1 if age>=15 & age<65
	
	*1.1. Education *
	* Highest levels of education 
	gen edu_lvl_f2f=1 if (hh_c06==2 | inrange(hh_c08,0,5))
	replace edu_lvl_f2f=1 if hh_c08==. 
	replace edu_lvl_f2f=2 if (inrange(hh_c08,6,13))
	replace edu_lvl_f2f=3 if (inrange(hh_c08,14,18))
	replace edu_lvl_f2f=4 if (inrange(hh_c08,19,23))
	lab define edu_lvl_f2f 1 "None" 2 "Primary" 3 "Secondary" 4 "Tertiary"
	gen edulvl_adult_f2f=edu_lvl_f2f if adult_head==1
	gen edulvl_youth_f2f=edu_lvl_f2f if youth_head==1

	* Years of education  // to verify 
	gen edu_yrs_f2f=0 if hh_c06==2 | hh_c08==0 | hh_c08==.
	replace edu_yrs_f2f=1 if hh_c08==1 | hh_c08==51
	replace edu_yrs_f2f=2 if hh_c08==2
	replace edu_yrs_f2f=3 if hh_c08==3
	replace edu_yrs_f2f=4 if hh_c08==4
	replace edu_yrs_f2f=5 if hh_c08==5	
	replace edu_yrs_f2f=6 if hh_c08==6
	replace edu_yrs_f2f=7 if hh_c08==7	
	replace edu_yrs_f2f=8 if hh_c08==8
	replace edu_yrs_f2f=9 if hh_c08==9 
	replace edu_yrs_f2f=10 if hh_c08==10
	replace edu_yrs_f2f=11 if hh_c08==11
	replace edu_yrs_f2f=12 if hh_c08==12
	replace edu_yrs_f2f=13 if hh_c08==13
	replace edu_yrs_f2f=14 if hh_c08==14 
	replace edu_yrs_f2f=15 if hh_c08==15 | hh_c08==20
	replace edu_yrs_f2f=16 if hh_c08==16 | hh_c08==21
	replace edu_yrs_f2f=17 if hh_c08==17 | hh_c08==22
	replace edu_yrs_f2f=18 if hh_c08==18 | hh_c08==23 
	replace edu_yrs_f2f=19 if hh_c08==19 
	gen eduyrs_adult_f2f=edu_yrs_f2f if adult_head==1
	gen eduyrs_youth_f2f=edu_yrs_f2f if youth_head==1
	
	/*Categorical education variable
	gen education=0 if hh_c06==2 | hh_c08==0 
	replace education=8 if inrange(hh_c08,1,8)  
	replace education=14 if inrange(hh_c08,9,14) 
	replace education=18 if inrange(hh_c08,15,19) | inrange(hh_c08,20,23)*/
	

	*1.2. Employment and occupation of the head of HH (not youth)*
	* Wage work
	gen wage_work_f2f_curr=(hh_e11>0) 								 											// current wage work
	gen wage_work_f2f2_abs=(hh_e14==1 & hh_e15!=2 & hh_e15_3==2) 		 										// temporary absence (<3 months)
	gen wage_work_f2f2_12=(hh_e06_4==1) 																		// last 12-months wage work
	gen wage_work_f2f_7days=(wage_work_f2f_curr + wage_work_f2f2_abs>0)    										// last 7 days wage work
	
	gen wage_work_f2f=(wage_work_f2f_7days==1 | wage_work_f2f2_12 ==1) & adult_head==1 							// total wage work
	gen stem_f2f=(wage_work_f2f==1) & ((inrange(hh_e20b,69,75)) | (inrange(hh_e20b,86,88))) & adult_head==1  	// stem jobs
	
	* Ag work
	gen ag_work_f2f_curr= hh_e07a>0 & (inlist(hh_e07a_1,1,2)) 													// current ag work 
	gen ag_work_f2f_abs=(hh_e14==1 & hh_e15==2 & hh_e15_3==1) & (inlist(hh_e15_4,1,2)) 							// temporary absence (<3 months)
	gen ag_work_f2f_12=(hh_e06_1a==1) 																			// last 12-months ag work
	gen ag_work_f2f_7days=(ag_work_f2f_curr + ag_work_f2f_abs>0) 												// last 7 days ag work
	
	gen ag_work_f2f=(ag_work_f2f_7days==1 | ag_work_f2f_12 ==1) & adult_head==1 								// total ag work
	
	*Own account work
	gen own_work_f2f_curr=(hh_e08>0 | hh_e09>0)	 							 									// current own work
	gen own_work_f2f_12=(hh_e06_2==1 | hh_e06_3==1)																// last 12-months own work 
	
	gen own_work_f2f=(own_work_f2f_curr==1 | own_work_f2f_12==1) & adult_head==1 								// total own work
	
// collapsing all vrbs at hh level // 
collapse (max)  hh_wgt youth_head adult_head hhsize edu_lvl_f2f edulvl_adult_f2f edulvl_youth_f2f wage_work_f2f stem_f2f ag_work_f2f own_work_f2f (median) eduyrs_adult_f2f edu_yrs_f2f eduyrs_youth_f2f (sum) dependent independent, by(y4_hhid ea_id)

	replace independent=1 if (independent==0 & dependent>0)
	gen	dependency_ratio = dependent/independent 
	tab dependency_ratio, m

	count if (independent==0 & dependent==0) | (independent==0 & dependent>0) // >> missing values
	count if (independent>0 & dependent==0) // >> 0
	
	replace edulvl_adult_f2f=edulvl_youth_f2f if edulvl_adult_f2f==. & youth_head==1  
	replace edulvl_adult_f2f=1 if edulvl_adult_f2f==. & adult_head==1
	replace edu_lvl_f2f=1 if edu_lvl_f2f==. & adult_head==1

	replace eduyrs_adult_f2f=eduyrs_youth_f2f if eduyrs_adult_f2f==. & youth_head==1
	replace eduyrs_adult_f2f=1 if eduyrs_adult_f2f==. & adult_head==1
	replace edu_yrs_f2f=1 if edu_yrs_f2f==. & adult_head==1

	drop edulvl_youth_f2f dependent independent eduyrs_youth_f2f
	
	rename y4_hhid  household_id
	
	isid household_id

tempfile all_f2f
save `all_f2f', replace 

 

***************** 2. Personal characteristics of the youth *********************
// High Frequency Phone Survey 2020-2023 // Round 10 //
use "$malawi_youth\sect5f_Aspirations_r10.dta", clear
rename PID pid
merge 1:1 y4_hhid pid using "$malawi_youth\sect2_Household_Roster_r10.dta"
keep if _m==3  // only selected youth
drop _m
merge 1:m y4_hhid using "$malawi_youth\secta_Cover_Page_r10.dta"
keep if _m==3  // only completed interviews
drop _m

	gen youth_head2=(preload_relation==1) if current_age<26
	recode youth_head2 (.=0)

	* The oldest / youngest youth *
	bysort y4_hhid: egen oldest=max(current_age) if current_age>=15 & current_age<=25
	
	bysort y4_hhid: egen youngest=min(current_age) if current_age>=15 & current_age<=25

	* 2.1. Sex*
	gen female=(preload_sex==2)
	
	* 2.2. Age*
	keep if inrange(current_age,15,25) //keep only youth - 910 observations
	rename current_age age
	gen age_group=.
	replace age_group=1 if inrange(age,15,18)
	replace age_group=2 if inrange(age,19,22)
	replace age_group=3 if inrange(age,23,25)
	gen age_group1518=(age_group==1) 
	gen age_group1922=(age_group==2) 
	gen age_group2325=(age_group==3)
	
	* 2.3. Education of the head of HH *
	* Highest level of education 
	gen edu_youth=1 if (s5eq2==2 | s5eq8==1)
	replace edu_youth=2 if (s5eq8==2)
	replace edu_youth=3 if (inlist(s5eq8,3,4))
	replace edu_youth=4 if (inlist(s5eq8,7,8))
	replace edu_youth=5 if (inlist(s5eq8,11,12,96))
	lab define edu_youth 1 "None" 2 "Primary" 3 "Secondary" 4 "Tertiary" 5 "University"
	gen none=(edu_youth==1) 
	gen primary=(edu_youth==2)
	gen secondary=(edu_youth==3)
	gen tertiary=(edu_youth==4)
	gen university=(edu_youth==5)


	* Years*
	gen edu_youth_yrs=0 if s5eq2==2 | s5eq11==0 
	replace edu_youth_yrs=1 if s5eq11==11 
	replace edu_youth_yrs=2 if s5eq11==12
	replace edu_youth_yrs=3 if s5eq11==13
	replace edu_youth_yrs=4 if s5eq11==14
	replace edu_youth_yrs=5 if s5eq11==15	
	replace edu_youth_yrs=6 if s5eq11==16
	replace edu_youth_yrs=7 if s5eq11==17	
	replace edu_youth_yrs=8 if s5eq11==18
	replace edu_youth_yrs=9 if s5eq11==21 
	replace edu_youth_yrs=10 if s5eq11==22
	replace edu_youth_yrs=11 if s5eq11==23
	replace edu_youth_yrs=12 if s5eq11==24
	replace edu_youth_yrs=13 if s5eq11==31
	replace edu_youth_yrs=14 if s5eq11==32
	replace edu_youth_yrs=15 if s5eq11==41 
	replace edu_youth_yrs=16 if s5eq11==42 
	replace edu_youth_yrs=17 if s5eq11==43 
	replace edu_youth_yrs=18 if s5eq11==44 
	replace edu_youth_yrs=19 if s5eq11==96
	replace edu_youth_yrs=0 if s5eq8==1 & s5eq10==2
	replace edu_youth_yrs=8 if s5eq8==2 & s5eq10==2
	replace edu_youth_yrs=12 if (s5eq8==3 | s5eq8==4) & s5eq10==2
	replace edu_youth_yrs=13 if (s5eq8==7 | s5eq8==8) & s5eq10==2
	replace edu_youth_yrs=16 if s5eq8==11 & s5eq10==2
	replace edu_youth_yrs=17 if s5eq8_oth=="COLLEGE DIPLOMA" | s5eq8_oth=="diploma in Public health"
	replace edu_youth_yrs=18 if s5eq8==12 & s5eq10==2
	
	/*Categorical education variable
	gen education=0 if s5eq8==1 | s5eq2==2
	replace education=8 if s5eq8==2 
	replace education=14 if s5eq8==3 | s5eq8==4
	replace education=18 if inlist(s5eq8,7,8,12,11,96) */

	* 2.4. Ideal job characteristic: Interesting job to do*
	gen interest_chr=(s5eq25a==1 & s5eq25b!=1) | (s5eq25a==1 & s5eq25b==1) | (s5eq25a!=1 & s5eq25b==1)
	
	* 2.5. Ideal job characteristic: Well paid job*
	gen remunerative =(s5eq25a==3 & s5eq25b!=3) | (s5eq25a==3 & s5eq25b==3) | (s5eq25a!=3 & s5eq25b==3)	
	
	* 2.6. Main influencing factor: Youth interest in the tasks*
	gen interest_fct =(s5eq26__3==3) 
	
	* 2.7. Likelihood to achieve the dream job (self-efficacy)* 
	gen likelihood=(s5eq28) if s5eq27==2 
	replace likelihood=6 if likelihood==.
	
	* 2.8. Constraint to achieve the dream job: Lack of money*
	gen lack_money=(s5eq29a==1 & s5eq29b==1) | (s5eq29a==1 & s5eq29b!=1) | (s5eq29a!=1 & s5eq29b==1)

	* 2.9. Constraint to achieve the dream job: Domestic obligation*
	gen domestic_work =((s5eq29a==8 & s5eq29b!=8) | (s5eq29a==8 & s5eq29b==8) | (s5eq29a!=8 & s5eq29b==8)) 
	//| ((s5eq29a==10 & s5eq29b!=10) | (s5eq29a==10 & s5eq29b==10) | (s5eq29a!=10 & s5eq29b==10))
	
	* 2.10. Ideal levl of education: university*
	gen ideal_uni=(s5eq22==4)
	replace ideal_uni=1 if s5eq22_os=="nursing"
	replace ideal_uni=1 if s5eq22_os=="training college"
	
	* 2.11. Ideal levl of education: post-graduate*
	gen ideal_postgrad=(s5eq22==5)
	
	* 2.12. Currently doing ideal job*
	gen ideal_job=(s5eq27==1)
	
	* 2.13. Currently doing a paid job*
	gen paid_job=(s5eq4==1 | s5eq14==1)
	
	* 2.14. Currently agriculture worker*
	gen ag_job=(s5eq4==2 | s5eq14==2)
	
	* 2.15. Currently attending school *
	gen training=(s5eq4==4)
	replace training=1 if s5eq14==4
	gen attending_schoolt=s5eq10
	recode attending_schoolt (2=0) (.=0)
	replace attending_schoolt=1 if training==1
	
	* 2.16. Currently working (either paid job or farming) *
	gen working=(paid_job==1 | ag_job==1 )
	gen ideal_job_curr=(s5eq27==1 & working==1)
	
	* 2.17. NEET *
	gen neitherw_s=(working==0 & attending_schoolt==0)
	
	* 2.18. Age start working *
	replace s5eq6=. if s5eq6==-98 | s5eq6==-99
	replace s5eq16=. if s5eq16==-98 | s5eq16==-99
	gen age_working=s5eq6 
	replace age_working=s5eq16 if s5eq6==. 
	replace age_working=15 if age_working==2015
	replace age_working=19 if age_working==2019
	replace age_working=20 if age_working==2020

	gen working_child14=(age_working<15) 
	gen working_youth1518=(age_working>=15 & age_working<19) 
	gen working_youth1922=(age_working>=19 & age_working<23)  
	gen working_youth2325=(age_working>=23 & age_working<=25) 
	replace age_working=. if age_working>25
	
	
*************************** 3. Community characteristics ***********************

	* 3.1. Ideal job characteristic: Job that family and friends regard highly*
	gen status_chr=(s5eq25a==2 & s5eq25b!=2) | (s5eq25a==2 & s5eq25b==2) | (s5eq25a!=2 & s5eq25b==2)
	
	* 3.2. Main influencing factor: Family and friends*
	gen status_fct =(s5eq26__1==1) 
	
	* 3.3. Sector (urban)* 
	gen urban=(urb_rural==1)

	* 3.4. Any other woman doing his/her dream job (Role Model)*
	gen role_model_w=(s5eq31==1)
	
	* Anyone doing his/her dream job (Role Model)*
	gen role_model=(s5eq30==1) 
	
	
***************************** 4. Youths Aspirations ****************************

*Dummies: ideal job is... 
gen stem_job=(inlist(s5eq24b,11,14,31))
gen stem_exp=likelihood if stem_job==1
replace stem_exp=0 if likelihood<=2
replace stem_exp=1 if likelihood>2
rename likelihood expectation
gen likely= inlist(expectation,4,5,6)

*Dummies: ideal education is...
gen ideal_uniabove=(ideal_uni==1 | ideal_postgrad==1) 
	* Educational gap *
	gen curr_uniabove=.
	replace curr_uniabove=0 if edu_youth<=3
	replace curr_uniabove=1 if edu_youth>3
	gen edu_aspgap=ideal_uniabove-curr_uniabove // Ray (2006) definition
	tab edu_aspgap
	
*Dummy: considering leaving the community to look for better job opportunities
gen migration=(s5eq36==1)

* Anyone doing his/her dream job (Role Model)*
gen role_model_stem=(s5eq30==1) if stem_job==1
replace role_model_stem=0 if role_model_stem==.

rename y4_hhid household_id

// collapsing all vrbs at hh level //	
collapse (max) youth_head2 stem_job ideal_uniabove migration female age_group age_group1518 age_group1922 age_group2325 none primary secondary tertiary university attending_schoolt working ideal_job_curr paid_job ag_job  neitherw_s working_child14 working_youth1518 working_youth1922 working_youth2325 urban interest_chr role_model status_chr likely oldest edu_youth edu_aspgap lack_money s5eq37__1 s5eq37__2 s5eq37__3 s5eq37__4 s5eq37__5 (median) age edu_youth_yrs age_working, by(household_id)

isid household_id
	
tempfile all_youth
save `all_youth', replace
	

********************************* 5.Remittances ********************************
// High Frequency Phone Survey 2020-2023 //	Round 5 //
	use "$malawi_youth\sect6c_otherincome_r5", clear
	numlabel, add
	rename y4_hhid household_id

	rename s6cq1 remittance1	
	rename s6cq2 remittance2

	tab1 remittance1 remittance2
	recode remittance1 (2=0) 
	recode remittance2 (2=0)
	
	collapse (max) remittance1 remittance2, by(household_id) 
	replace remittance2=0 if remittance2==.a
	
	isid household_id

	tempfile remittances
	save `remittances', replace
	
	
	use "$malawi_f2f_19\hh_mod_a_filt_19.dta", clear
	merge 1:1 y4_hhid using "$malawi_youth\sect6c_otherincome_r5"
	numlabel, add
	rename s6cq1 remittance1_EA	
	rename s6cq2 remittance2_EA
	recode remittance1_EA (2=0) 
	recode remittance2_EA (2=0)
	
	collapse (max) remittance1_EA remittance2_EA, by(ea_id) 
	
	isid ea_id

	tempfile remittances_ea
	save `remittances_ea', replace
	
	
************************** 6. Consumption aggregates ***************************
// Integrated Panel Household Survey 2010-2013 //
use "$malawi_f2f_13\Round 2 (2013) Consumption Aggregate.dta", clear
	keep y2_hhid ea_id rexpagg hhweight
	rename y2_hhid y4_hhid
	merge 1:1 y4_hhid using "$malawi_youth\asset_index_panel_2019.dta"
	drop _merge
	svyset ea_id [weight=hhweight]
	xtile cons_quint=rexpagg [weight=hhweight], n(5)
	tab cons_quint, m
	replace cons_quint = wealthquintile if cons_quint==.
	
	gen cons_quint1=(cons_quint==1)
	gen cons_quint2=(cons_quint==2)
	gen cons_quint3=(cons_quint==3)
	gen cons_quint4=(cons_quint==4)
	gen cons_quint5=(cons_quint==5)
	
	drop wealthquintile rexpagg
	rename y4_hhid household_id
	isid household_id
	
tempfile cons_f2f
save `cons_f2f', replace 
	
	
	
******************************** merging datasets ******************************		
use `all_f2f'
merge 1:1 household_id using `all_youth'
keep if _m==3
drop _merge
merge 1:1 household_id using `remittances'
keep if _m==3
drop _merge
merge 1:1 household_id using `cons_f2f'
keep if _m==3
drop _merge
merge m:1 ea_id using `remittances_ea'
keep if _m==3
drop _merge

gen country=2
rename hh_wgt weights 
rename household_id y4_hhid

* 8% of the youth are head of the HH *
count if youth_head==1 & youth_head2==1 // 72 youth head of HH in the phone survey were also youth head of HH in the f-2-f
count if youth_head!=1 & youth_head2==1 // 2 youth head of HH in the phone survey were not youth head of HH in the f-2-f
	
drop youth_head adult_head hhweight


* Labelling variables *
lab var country "country"
lab var weights "HH weights"
lab var ea_id "EA ID"
lab var y4_hhid "HH ID"
lab var youth_head2 "Youth head of the HH"
lab var urban "Sector is Urban"
lab var hhsize "Size of the HH - F2F"
lab var dependency_ratio "Dependency ratio - F2F"
lab var edu_lvl_f2f "Highest level of education of HH members - F2F"
lab var edulvl_adult_f2f "Highest level of education of adult head of HH - F2F"
lab var edu_yrs_f2f "Average education of HH members - F2F"
lab var eduyrs_adult_f2f "Average education of adult head of HH - F2F"
lab var wage_work_f2f "Head of HH working in wage job- F2F"
lab var stem_f2f "Head of HH working in STEM related jobs - F2F"
lab var ag_work_f2f "Head of HH working in agriculture - F2F"
lab var own_work_f2f "Head of HH is own account worker - F2F"
lab var cons_quint "Consumption quintile – F2F"
lab var cons_quint1 "1st Consumption quintile (poorest)"
lab var cons_quint2 "2nd Consumption quintile"
lab var cons_quint3 "3rd Consumption quintile"
lab var cons_quint4 "4th Consumption quintile"
lab var cons_quint5 "5th Consumption quintile (richest)"
lab var female "Youth is female"
lab var age_group "Youth age group (full sample, 15-25)"
lab var age_group1518 "15-18 years old"
lab var age_group1922 "19-22 years old"
lab var age_group2325 "23-25 years old"
lab var oldest "The oldest youth"
lab var age_working "Youth age start working (full sample, 15-25)"
lab var edu_youth "Youth education (highest levels of education)"
lab var edu_youth_yrs "Youth education (years of education)"
lab var paid_job "Youth currently doing a paid job"
lab var ag_job "Youth currently agriculture worker"
lab var working "Youth currently working (either paid job or farming)"
lab var attending_schoolt "Youth currently attending school"
lab var neitherw_s "Youth currently neither working or attending school"
lab var ideal_job_curr "Youth currently doing the ideal job"
lab var interest_chr "Ideal job characteristic: Interesting job to do"
lab var status_chr "Ideal job characteristic: Job that family and friends regard highly"
lab var lack_money "Ideal job constraint: Lack of money"
lab var likely "Youth likelihood to reach the dream job"
lab var role_model "Youth knows someone in the community that has your dream job"
lab var stem_job "Ideal job: STEM related work"
lab var migration "Youth is considering leaving the community to look for better job opportunities"
lab var s5eq37__1 "Moving to capital city"
lab var s5eq37__2 "Moving to a town/city"
lab var s5eq37__3 "Moving to rural area"
lab var s5eq37__4 "Moving to another country"
lab var s5eq37__5 "Moving to - no preference"
label var working_child14 "Started working below 14 years old"
label var working_youth1518 "Started working between 15 and 18 years old"
label var working_youth1922 "Started working between 19 and 22 years old"
label var working_youth2325 "Started working between 23 and 25 years old"
lab define edu_youth 1 "None" 2 "Primary" 3 "Secondary" 4 "Tertiary" 5 "University"
label var edu_aspgap "Educational gap"
label var none "No degree"
label var primary "Primary"
label var secondary "Secondary"
label var tertiary "Tertiary"
label var university "University"
label var ideal_uniabove "Ideal level of education: university and above"
lab var remittance1 "HHs with remittances from abroad"
lab var remittance2 "HHs with remittances from family within the country"
label var remittance1_EA "HHs with remittances from abroad within EA"
label var remittance2_EA "HHs with remittances from family within EA"
label var age "Age (in years)"

isid y4_hhid

// Saving the final dataset for analysis //
save "$malawi_final\malawi.dta", replace

clear
capture log close