******************************************************************
**  Country: Nigeria                                            **
**                                                              **
**  Description: Creates variables for empirical analysis       **
**                                                              **
**  Program first written: January 2022 (Valentina Costa)   	**
**  Program last revised:  September 2023 		                ** 
******************************************************************

******************************************************************
*** SET OF VARIABLES ***
******************************************************************
* 1. Family characteristics (General Household Survey-Panel Wave 4 (2018/19))
* 2. Personal characteristics of the youth (COVID-19 National Longitudinal Phone Survey 2020-2021 Phase 1)
* 3. Community characteristics (COVID-19 National Longitudinal Phone Survey 2020-2021 Phase 1)
* 4. Youths Aspirations (COVID-19 National Longitudinal Phone Survey 2020-2021 Phase 1)
* 5. Remittances (COVID-19 National Longitudinal Phone Survey 2020-2021 Phase 1)
* 6. Consumption aggregates (General Household Survey-Panel Wave 4 (2018/19) Post-Harvest Visit)


clear
set more off
capture set max_memory 500M 
capture set mem 500M		

cap log close

************************* 1. Family characteristics ****************************
// GENERAL HOUSEHOLD SURVEY-PANEL Wave 4 (2018/19) //

* POST-HARVESTING SEASON *
use "$nigeria_f2f_panel\secta_harvestw4.dta", clear
	merge 1:m hhid using "$nigeria_f2f_panel\sect1_harvestw4.dta"
	keep if interview_result==1 												// keep only completed surveys
	drop _m
	merge 1:1 hhid indiv using "$nigeria_f2f_panel\sect2_harvestw4.dta"
	drop _m 																	// 3,780 HH member not in ph
	merge 1:1 hhid indiv using "$nigeria_f2f_panel\sect3a_harvestw4.dta"
	drop _m
	
	gen female =(s1q2==2)
	gen head=(s1q3==1)
	rename s1q4 age
	gene youth=(age<26)
	gen youth_head=(head==1) if youth==1  	// 1% of the youths are head of the HH
	gen adult_head=(head==1) if youth==0  	// 35% of the adults are head of the HH
	gen head_age=(youth==0) if head==1  	// 97% of the head of the HH are adults
	
	gen dependent=1 if age<15 | age>=65
	gen independent=1 if age>=15 & age<65
	
	
	*1.1. Education of the head of HH (not youth) * 
	* level of education
	gen edu_lvl_f2f = 1 if (s2aq6==2 | s2aq9==0 | inrange(s2aq9,11,15) | inlist(s2aq9,1,2,3,51))
	replace edu_lvl_f2f = 2 if (inrange(s2aq9,16,25) | s2aq9==27 | s2aq9==52)
	replace edu_lvl_f2f = 3 if (s2aq9==26 | inlist(s2aq9,321,28,33,61))
	replace edu_lvl_f2f = 4 if (inlist(s2aq9,41,411,412,421,422,423,424,43,322,31,34,35))
	lab define edu_lvl_f2f 1 "None" 2 "Primary" 3 "Secondary" 4 "Tertiary"
	
	gen edulvl_adult_f2f=edu_lvl_f2f if adult_head==1
	gen edulvl_youth_f2f=edu_lvl_f2f if youth_head==1
	
	* Years of education // to verify 
	gen edu_yrs_f2f=0 if s2aq6==2 | s2aq9==0
	replace edu_yrs_f2f=1 if s2aq9==1 | s2aq9==51
	replace edu_yrs_f2f=2 if s2aq9==2
	replace edu_yrs_f2f=3 if s2aq9==3
	replace edu_yrs_f2f=4 if s2aq9==11
	replace edu_yrs_f2f=5 if s2aq9==12	
	replace edu_yrs_f2f=6 if s2aq9==13
	replace edu_yrs_f2f=7 if s2aq9==14	
	replace edu_yrs_f2f=8 if s2aq9==15
	replace edu_yrs_f2f=9 if s2aq9==16  | s2aq9==27 | s2aq9==52
	replace edu_yrs_f2f=10 if s2aq9==21
	replace edu_yrs_f2f=11 if s2aq9==22
	replace edu_yrs_f2f=12 if s2aq9==23
	replace edu_yrs_f2f=13 if s2aq9==24
	replace edu_yrs_f2f=14 if s2aq9==25 
	replace edu_yrs_f2f=15 if s2aq9==26 | inlist(s2aq9,321,28,33,61)
	replace edu_yrs_f2f=16 if (inlist(s2aq9,41,411,412,421,322,31,34,35))
	replace edu_yrs_f2f=17 if s2aq9==422 
	replace edu_yrs_f2f=18 if s2aq9==423 
	replace edu_yrs_f2f=19 if s2aq9==424 | s2aq9==43
	
	gen eduyrs_adult_f2f=edu_yrs_f2f if adult_head==1
	gen eduyrs_youth_f2f=edu_yrs_f2f if youth_head==1

	*1.2. Employment and occupation of the head of HH (not youth) *
	* Wage work
	gen wage_work_f2f_curr_ph=(s3q4==1)							 												// current wage work 
	gen wage_work_f2f2_abs_ph=(s3q8a==1 & s3q8b!=6 & s3q8c==2) 	 												// temporary absence (<3 months)
	gen wage_work_f2f_ph=(wage_work_f2f_curr_ph + wage_work_f2f2_abs_ph>0)   									// current and temporary absent wage workers
	gen stem_f2f_ph=(wage_work_f2f_ph==1) & (inlist(s3q14,4,12))												// stem jobs

	* Ag work
	gen ag_work_f2f_curr_ph=(s3q5==1) & (inlist(s3q5c,1,2)) 		  											// current ag work
	gen ag_work_f2f_abs_ph=(s3q8a==1 & s3q8b==6 & s3q8c==1) & (inlist(s3q8d,1,2)) 			 					// temporary absence (<3 months)
	gen ag_work_f2f_ph=(ag_work_f2f_curr_ph + ag_work_f2f_abs_ph>0) 		 									// total ag workers

	*Own account work
	gen own_work_f2f_ph=(s3q6==1 & head==1)																		// current own work(nfe)
	
	tempfile ph
    save `ph', replace
	
	
* POST-PLANTING SEASON *
use "$nigeria_f2f_panel\secta_plantingw4.dta", clear
	merge 1:m hhid using "$nigeria_f2f_panel\sect1_plantingw4.dta"
	keep if interview_result==1 																				// keep only completed surveys
	drop _m 																									// keep also who's not HH member in pp 
	merge 1:1 hhid indiv using "$nigeria_f2f_panel\sect3_plantingw4.dta"
	drop _m 
	
	gen female =(s1q2==2)
	gen head=(s1q3==1)
	rename s1q4 age

	*1.3. Employment and occupation of the head of HH not youth *
	* Wage work
	gen wage_work_f2f_curr_pp=(s3q4==1)							 												// current wage work 
	gen wage_work_f2f2_abs_pp=(s3q8a==1 & s3q8b!=6 & s3q8c==2)  		 										// temporary absence (<3 months)
	gen wage_work_f2f_pp=(wage_work_f2f_curr_pp + wage_work_f2f2_abs_pp>0) 	 		    						// current and temporary absent wage workers
	gen stem_f2f_pp=(wage_work_f2f_pp==1) & (inlist(s3q14,4,12)) 

	* Ag work
	gen ag_work_f2f_curr_pp=(s3q5==1) & (inlist(s3q5c,1,2))														// current ag work
	gen ag_work_f2f_abs_pp=(s3q8a==1 & s3q8b==6 & s3q8c==1) & (inlist(s3q8d,1,2))    							// temporary absence (<3 months)
	gen ag_work_f2f_pp=(ag_work_f2f_curr_pp + ag_work_f2f_abs_pp>0) 		 									// current and temporary absent ag workers

	*Own account work
	gen own_work_f2f_pp=(s3q6==1) 																				// current own work(nfe)
	
	tempfile pp
    save `pp', replace	
	
	
	* Merging PP and PH **
	use `ph', clear
	merge 1:1 indiv hhid using `pp'
	drop _merge
	
	// Adult head employment //
	gen wage_work_f2f=(wage_work_f2f_ph==1 | wage_work_f2f_pp==1) & adult_head==1  
	gen stem_f2f=(stem_f2f_ph==1 | stem_f2f_pp==1) & adult_head==1 
	gen ag_work_f2f=(ag_work_f2f_ph==1 | ag_work_f2f_pp==1) & adult_head==1 
	gen own_work_f2f=(own_work_f2f_ph==1 | own_work_f2f_pp==1) & adult_head==1  

	// collapsing all vrbs at hh level // 	
collapse (max)  wt_wave4 youth_head adult_head edu_lvl_f2f edulvl_adult_f2f wage_work_f2f stem_f2f ag_work_f2f own_work_f2f edulvl_youth_f2f (median)eduyrs_adult_f2f edu_yrs_f2f eduyrs_youth_f2f (sum) dependent independent, by(hhid ea)
	
	replace independent=1 if (independent==0 & dependent>0)
	gen	dependency_ratio = dependent/independent
	tab dependency_ratio, m
	count if (independent==0 & dependent==0) | (independent==0 & dependent>0) // >> missing values
	count if (independent>0 & dependent==0) // >> 0

	replace edulvl_adult_f2f=edulvl_youth_f2f if edulvl_adult_f2f==. & youth_head==1 
	replace edulvl_adult_f2f=1 if edulvl_adult_f2f==. & adult_head==1
	replace edu_lvl_f2f=1 if edu_lvl_f2f==. & adult_head==1

	replace eduyrs_adult_f2f=eduyrs_youth_f2f if eduyrs_adult_f2f==. & youth_head==1 
	replace eduyrs_adult_f2f=1 if eduyrs_adult_f2f==. & adult_head==1
	replace edu_yrs_f2f=1 if edu_yrs_f2f==. & adult_head==1	
	
	duplicates tag hhid, gen(duptag)
	tab duptag // 6  total duplicates (3 pairs)
	br if duptag==1
	
	replace ea=670 if hhid==140073 & ea==0
	replace ea=334 if hhid==300035 & ea==0
	replace ea=276 if hhid==320077 & ea==0
	drop if edu_lvl_f2f==. & edu_yrs_f2f==. & (ea==670 | ea==334 | ea==276)

	drop duptag youth_head edulvl_youth_f2f dependent independent adult_head eduyrs_youth_f2f
	rename hhid household_id 
	isid household_id 
	
tempfile all_f2f
save `all_f2f', replace 
	

	
***************** 2. Personal characteristics of the youth *********************
// COVID-19 NATIONAL LONGITUDINAL PHONE SURVEY (COVID-19 NLPS) 2020 //
use "$nigeria_youth\r12_sect_5e_9a.dta", clear
merge 1:1 hhid indiv using "$nigeria_youth\r12_sect_2.dta"
drop _merge
merge m:1 hhid using "$nigeria_youth\r12_sect_a_12.dta"
keep if s5eq1a==1 // keep only completed interviews with the selected youth

	gen youth_head2=(s2q7_r11==1) if s2q6_r11<26  // 1.7% of youths are the head of the HH
	recode youth_head2 (.=0)

	* The oldest / youngest youth *
	bysort hhid: egen oldest=max(s2q6_r11) if s2q6_r11>=15 & s2q6_r11<=25
	bysort hhid: egen youngest=min(s2q6_r11) if s2q6_r11>=15 & s2q6_r11<=25
	drop if _m==2 
	drop _merge
	
	* 2.1. Sex*
	gen female=(s2q5_r11==2)
	
	* 2.2. Age*
	keep if inrange(s2q6_r11,15,25) //keep only youth - 974 observations
	rename s2q6_r11 age
	gen age_group=.
	replace age_group=1 if inrange(age,15,18)
	replace age_group=2 if inrange(age,19,22)
	replace age_group=3 if inrange(age,23,25)
	gen age_group1518=(age_group==1) 
	gen age_group1922=(age_group==2) 
	gen age_group2325=(age_group==3) 
	
	* 2.3. Education *
	* Highest levels of education 
	gen edu_youth=1 if (s5eq2==2 | s5eq8==1)
	replace edu_youth=2 if (s5eq8==2 | s5eq8==3)
	replace edu_youth=3 if (inlist(s5eq8,5,6))
	replace edu_youth=4 if (inlist(s5eq8,8,41,42))
	replace edu_youth=5 if (inlist(s5eq8,9,11))
	lab define edu_youth 1 "None" 2 "Primary" 3 "Secondary" 4 "Tertiary" 5 "University"
	gen none=(edu_youth==1) 
	gen primary=(edu_youth==2)
	gen secondary=(edu_youth==3)
	gen tertiary=(edu_youth==4)
	gen university=(edu_youth==5)
	
	* Years of education *
	gen edu_youth_yrs=0 if s5eq2==2 | s5eq11==0
	replace edu_youth_yrs=1 if s5eq11==1 | s5eq11==51
	replace edu_youth_yrs=2 if s5eq11==2
	replace edu_youth_yrs=3 if s5eq11==3
	replace edu_youth_yrs=4 if s5eq11==11
	replace edu_youth_yrs=5 if s5eq11==12	
	replace edu_youth_yrs=6 if s5eq11==13
	replace edu_youth_yrs=7 if s5eq11==14	
	replace edu_youth_yrs=8 if s5eq11==15
	replace edu_youth_yrs=9 if s5eq11==16  | s5eq11==27 | s5eq11==52
	replace edu_youth_yrs=10 if s5eq11==21
	replace edu_youth_yrs=11 if s5eq11==22
	replace edu_youth_yrs=12 if s5eq11==23
	replace edu_youth_yrs=13 if s5eq11==24
	replace edu_youth_yrs=14 if s5eq11==25 
	replace edu_youth_yrs=15 if s5eq11==26 
	replace edu_youth_yrs=16 if s5eq11==31 |  s5eq11==96
	replace edu_youth_yrs=18 if s5eq11==32 
	replace edu_youth_yrs=19 if s5eq11==33 

	replace edu_youth_yrs=0 if s5eq8==1 & s5eq10==2 
	replace edu_youth_yrs=6 if (s5eq8==2 | s5eq8==3) & s5eq10==2 
	replace edu_youth_yrs=9 if s5eq8==5 & s5eq10==2 
	replace edu_youth_yrs=12 if s5eq8==6 & s5eq10==2
	replace edu_youth_yrs=16 if (s5eq8==41 | s5eq8==42 | s5eq8==8) & s5eq10==2 
	replace edu_youth_yrs=18 if s5eq8==9 & s5eq10==2 
	replace edu_youth_yrs=19 if s5eq8==11 & s5eq10==2 
	
	/*Categorical education variable
	gen education=0 if s5eq10==2 | s5eq11==0
	replace education=8 if inrange(s5eq11,1,8) | s5eq11==51
	replace education=14 if inrange(s5eq11,16,25) | s5eq11==27 | s5eq11==52
	replace education=18 if (inlist(s5eq11,26,321,28,33,61,41,411,412,421,43,322,31,34,35,422,423,424))*/
	
	* 2.4. Ideal job characteristic: Interesting job to do*
	gen interest_chr=(s5eq25__1==1)
	
	* 2.5. Ideal job characteristic: Well paid job*
	gen remunerative=(s5eq25__3==1)
	
	* 2.6. Main influencing factor: Youth interest in the tasks*
	gen interest_fct=(s5eq26__3==1) 
	
	* 2.7. Likelihood to achieve the dream job (self-efficacy)* 
	gen likelihood=(s5eq28) if s5eq27==2 
	replace likelihood=6 if likelihood==.
	
	* 2.8. Constraint to achieve the dream job: Lack of money*
	gen lack_money=(s5eq29__1==1)
	
	* 2.9. Constraint to achieve the dream job: Domestic obligation*
	gen domestic_work=(s5eq29__8==1)
	*| s5eq29__10==1)
	
	* 2.10. Ideal level of education: university*
	gen ideal_uni=(s5eq22==4)
	replace ideal_uni=1 if s5eq22_os=="College of Education"
	replace ideal_uni=1 if s5eq22_os=="College of health"
	replace ideal_uni=1 if s5eq22_os=="Federal College of Education"
	replace ideal_uni=1 if s5eq22_os=="Federal college of education"
	replace ideal_uni=1 if s5eq22_os=="Nursing"
	replace ideal_uni=1 if s5eq22_os=="Polytechnic"
	replace ideal_uni=1 if s5eq22_os=="Polythenic"
	replace ideal_uni=1 if s5eq22_os=="School of nursing"
	
	* 2.11. Ideal levl of education: post-graduate*
	gen ideal_postgrad=(s5eq22==5)
	 
	* 2.12. Currently doing ideal job*
	gen ideal_job=(s5eq27==1)
	
	* 2.13. Currently doing a paid job*
	gen paid_job=(s5eq4==1 | s5eq14==1)
	
	* 2.14. Currently agriculture worker*
	gen ag_job=(s5eq4==2 | s5eq14==2)
	
	* 2.15. Currently attending school *
	gen training=(s5eq4==3)
	replace training=1 if s5eq14==3 // 72
	gen attending_schoolt=s5eq10
	recode attending_schoolt (2=0) (.=0)
	replace attending_schoolt=1 if training==1
	
	* 2.16. Currently working (either paid job or farming) *
	gen working=(paid_job==1 | ag_job==1 ) 
	gen ideal_job_curr=(s5eq27==1 & working==1)
	
	* 2.17. NEET *
	gen neitherw_s=(working==0 & attending_schoolt==0)
	
	* 2.18. Age start working *
	replace s5eq6=. if s5eq6==-98 | s5eq6==-99
	replace s5eq16=. if s5eq16==-98 | s5eq16==-99
	gen age_working=s5eq6 
	replace age_working=s5eq16 if s5eq6==. 
	
	gen working_child14=(age_working<15) 
	gen working_youth1518=(age_working>=15 & age_working<19) 
	gen working_youth1922=(age_working>=19 & age_working<23)  
	gen working_youth2325=(age_working>=23 & age_working<=25) 
	replace age_working=. if age_working>25
	
	
*************************** 3. Community characteristics ***********************
	* 3.1. Ideal job characteristic: Job that family and friends regard highly*
	gen status_chr=(s5eq25__2==1)
	
	* 3.2. Main influencing factor: Family and friends*
	gen status_fct =(s5eq26__1==1) 

	* 3.3. Sector (urban)* 
	gen urban=(sector==1)
	
	* 3.4. Any other woman doing his/her dream job (Role Model)*
	gen role_model_w=(s5eq31==1)
	
	* 3.5. Anyone doing his/her dream job (Role Model)*
	gen role_model=(s5eq30==1)	

	
************************** 4. Youths Aspirations *******************************
*Dummies: ideal job is... 
gen stem_job=(inlist(s5eq24b,11,14,31))
	gen stem_exp=likelihood if stem_job==1
	replace stem_exp=0 if likelihood<=2
	replace stem_exp=1 if likelihood>2
	rename likelihood expectation
	gen likely= inlist(expectation,4,5,6)

*Dummies: ideal education is...
gen ideal_uniabove=(ideal_uni==1 | ideal_postgrad==1) 
	* Educational gap *
	gen curr_uniabove=.
	replace curr_uniabove=0 if edu_youth<=3
	replace curr_uniabove=1 if edu_youth>3
	gen edu_aspgap=ideal_uniabove-curr_uniabove // Ray (2006) definition
	tab edu_aspgap
	recode edu_aspgap (-1=0)

*Dummy: considering leaving the community to look for better job opportunities
gen migration=(s5eq36==1)

* Anyone doing his/her dream job in STEM (Role Model)*
gen role_model_stem=(s5eq30==1) if stem_job==1
replace role_model_stem=0 if role_model_stem==.

// collapsing all vrbs at hh level //	
collapse (max) youth_head2 stem_job ideal_uniabove migration female age_group age_group1518 age_group1922 age_group2325 none primary secondary tertiary university attending_schoolt working ideal_job_curr paid_job ag_job  neitherw_s working_child14 working_youth1518 working_youth1922 working_youth2325 urban interest_chr role_model status_chr oldest edu_youth edu_aspgap likely lack_money s5eq37__1 s5eq37__2 s5eq37__3 s5eq37__4 s5eq37__5 (median) age edu_youth_yrs age_working, by(hhid ea)

rename hhid household_id 
isid household_id
 
tempfile all_youth
save `all_youth', replace


********************************* 5.Remittances ********************************
use "$nigeria_youth\r1_sect_7.dta", clear			
	keep if inlist(source_cd,4,5,99)
	recode s7q1 (2=0)
	rename s7q* s7q*_

	drop source_cd_os
	reshape wide s7q1 s7q2, i(hhid) j(source_cd)

	rename s7q1_4 remittance1
	rename s7q1_5 remittance2
	tab1 remittance1 remittance2
	
	collapse (max) remittance1 remittance2, by(hhid ea) 
	rename hhid household_id 
	
	isid household_id

	tempfile remittances
	save `remittances', replace
	
	
use "$nigeria_youth\r1_sect_7.dta", clear			
	keep if inlist(source_cd,4,5,99)
	recode s7q1 (2=0)
	rename s7q* s7q*_

	drop source_cd_os
	reshape wide s7q1 s7q2, i(hhid) j(source_cd)

	rename s7q1_4 remittance1_EA
	rename s7q1_5 remittance2_EA
	
	collapse (max) remittance1_EA remittance2_EA, by(ea) 
	
	isid ea

	tempfile remittances_ea
	save `remittances_ea', replace
	
************************** 6. Consumption aggregates ***************************
use "$nigeria_f2f_panel\totcons_final.dta", clear
	xtile cons_quint=totcons_adj_norm [weight=wt_wave4], n(5)
	tab cons_quint, m
	
	gen cons_quint1=(cons_quint==1)
	gen cons_quint2=(cons_quint==2)
	gen cons_quint3=(cons_quint==3)
	gen cons_quint4=(cons_quint==4)
	gen cons_quint5=(cons_quint==5)

	keep hhid ea wt_wave4 hhsize cons_quint cons_quint1 cons_quint2 cons_quint3 cons_quint4 cons_quint5
	rename hhid household_id 
	
	isid household_id
	
tempfile cons_f2f
save `cons_f2f', replace 
		

******************************** merging datasets ******************************		
use `all_f2f'
merge 1:1 household_id using `all_youth'
keep if _m==3
drop _merge
merge 1:1 household_id using `remittances'
keep if _m==3
drop _merge
merge 1:1 household_id using `cons_f2f'
keep if _m==3
drop _merge
merge m:1 ea using `remittances_ea'
keep if _m==3
drop _merge

gen country=3
rename wt_wave4 weights 

tostring ea, gen(ea_id)
tostring household_id, gen(y4_hhid)
drop ea household_id


 * Labelling variables *
lab var country "country"
lab var weights "HH weights"
lab var ea_id "EA ID"
lab var y4_hhid "HH ID"
lab var youth_head2 "Youth head of the HH"
lab var urban "Sector is Urban"
lab var hhsize "Size of the HH - F2F"
lab var dependency_ratio "Dependency ratio - F2F"
lab var edu_lvl_f2f "Highest level of education of HH members - F2F"
lab var edulvl_adult_f2f "Highest level of education of adult head of HH - F2F"
lab var edu_yrs_f2f "Average education of HH members - F2F"
lab var eduyrs_adult_f2f "Average education of adult head of HH - F2F"
lab var wage_work_f2f "Head of HH working in wage job- F2F"
lab var stem_f2f "Head of HH working in STEM related jobs - F2F"
lab var ag_work_f2f "Head of HH working in agriculture - F2F"
lab var own_work_f2f "Head of HH is own account worker - F2F"
lab var cons_quint "Consumption quintile – F2F"
lab var cons_quint1 "1st Consumption quintile (poorest)"
lab var cons_quint2 "2nd Consumption quintile"
lab var cons_quint3 "3rd Consumption quintile"
lab var cons_quint4 "4th Consumption quintile"
lab var cons_quint5 "5th Consumption quintile (richest)"
lab var female "Youth is female"
lab var age_group "Youth age group (full sample, 15-25)"
lab var age_group1518 "15-18 years old"
lab var age_group1922 "19-22 years old"
lab var age_group2325 "23-25 years old"
lab var oldest "The oldest youth"
lab var age_working "Youth age start working (full sample, 15-25)"
lab var edu_youth "Youth education (highest levels of education)"
lab var edu_youth_yrs "Youth education (years of education)"
lab var paid_job "Youth currently doing a paid job"
lab var ag_job "Youth currently agriculture worker"
lab var working "Youth currently working (either paid job or farming)"
lab var attending_schoolt "Youth currently attending school"
lab var neitherw_s "Youth currently neither working or attending school"
lab var ideal_job_curr "Youth currently doing the ideal job"
lab var interest_chr "Ideal job characteristic: Interesting job to do"
lab var status_chr "Ideal job characteristic: Job that family and friends regard highly"
lab var lack_money "Ideal job constraint: Lack of money"
lab var likely "Youth likelihood to reach the dream job"
lab var role_model "Youth knows someone in the community that has your dream job"
lab var stem_job "Ideal job: STEM related work"
lab var migration "Youth is considering leaving the community to look for better job opportunities"
lab var s5eq37__1 "Moving to capital city"
lab var s5eq37__2 "Moving to a town/city"
lab var s5eq37__3 "Moving to rural area"
lab var s5eq37__4 "Moving to another country"
lab var s5eq37__5 "Moving to - no preference"
label var working_child14 "Started working below 14 years old"
label var working_youth1518 "Started working between 15 and 18 years old"
label var working_youth1922 "Started working between 19 and 22 years old"
label var working_youth2325 "Started working between 23 and 25 years old"
lab define edu_youth 1 "None" 2 "Primary" 3 "Secondary" 4 "Tertiary" 5 "University"
label var edu_aspgap "Educational gap"
label var none "No degree"
label var primary "Primary"
label var secondary "Secondary"
label var tertiary "Tertiary"
label var university "University"
label var ideal_uniabove "Ideal level of education: university and above"
lab var remittance1 "HHs with remittances from abroad"
lab var remittance2 "HHs with remittances from family within the country"
label var remittance1_EA "HHs with remittances from abroad within EA"
label var remittance2_EA "HHs with remittances from family within EA"
label var age "Age (in years)"

isid y4_hhid

// Saving the final dataset for analysis //
save "$nigeria_final\nigeria.dta", replace
ex

clear
capture log close