******************************************************************
**  Countries: Nigeria, Malawi, Ethiopia                        **
**                                                              **
**  DEscription: Tables 1, 2 and 3 of the Aspirations paper    	**
**                                                              **
**  Program first written: January 2022 (Valentina Costa) 		**
**  Program last revised:  March 2024 		                ** 
******************************************************************
use "$pooled.dta", replace  

egen EA=group(country ea_id)


** Table 1 Educational Aspirations **

*Overall*
logit ideal_uniabove female i.age_group i.edu_youth working_child14 working_youth1518 working_youth1922 working_youth2325 stem_job oldest i.edulvl_adult_f2f wage_work_f2f ag_work_f2f own_work i.cons_quint urban [pw = weights], cluster (EA)

margins, dydx (female i.age_group i.edu_youth working_child14 working_youth1518 working_youth1922 working_youth2325 stem_job oldest i.edulvl_adult_f2f wage_work_f2f ag_work_f2f own_work i.cons_quint urban)
eststo margin: margins, dydx(female i.age_group i.edu_youth working_child14 working_youth1518 working_youth1922 working_youth2325 stem_job oldest i.edulvl_adult_f2f wage_work_f2f ag_work_f2f own_work i.cons_quint urban) post 

outreg2  using "$tables\Table 1.xls",  label append ctitle(Pooled sample)

*By country*
foreach x in 1 2 3 {
preserve
keep if country==`x'
logit ideal_uniabove female i.age_group i.edu_youth working_child14 working_youth1518 working_youth1922 working_youth2325 stem_job oldest i.edulvl_adult_f2f wage_work_f2f ag_work_f2f own_work i.cons_quint urban [pw=weights], cluster (ea_id)

margins, dydx (female i.age_group i.edu_youth working_child14 working_youth1518 working_youth1922 working_youth2325 stem_job oldest i.edulvl_adult_f2f wage_work_f2f ag_work_f2f own_work i.cons_quint urban)

eststo margin: margins, dydx(female i.age_group i.edu_youth working_child14 working_youth1518 working_youth1922 working_youth2325 stem_job oldest i.edulvl_adult_f2f wage_work_f2f ag_work_f2f own_work i.cons_quint urban) post

outreg2 using "$tables\Table 1.xls", label append ctitle(`x')

restore
}
 
 

** Table 2 Labor Aspirations **

*Overall*
logit stem_job female i.age_group edu_aspgap working_child14 working_youth1518 working_youth1922 working_youth2325 interest_chr likely hhsize stem_f2f i.cons_quint urban status_chr [pw=weights], cluster (EA)
margins, dydx (female i.age_group edu_aspgap working_child14 working_youth1518 working_youth1922 working_youth2325 interest_chr likely hhsize stem_f2f i.cons_quint urban status_chr)
eststo margin: margins, dydx(female i.age_group edu_aspgap working_child14 working_youth1518 working_youth1922 working_youth2325 interest_chr likely hhsize stem_f2f i.cons_quint urban status_chr) post 

outreg2 using "$tables\Table 2.xls", label append ctitle(Pooled sample)

*By country*
foreach x in 1 2 3 {
preserve
keep if country==`x'
logit stem_job female i.age_group edu_aspgap working_child14 working_youth1518 working_youth1922 working_youth2325 interest_chr likely hhsize stem_f2f i.cons_quint urban status_chr [pw=weights], cluster (EA)
margins, dydx (female i.age_group edu_aspgap working_child14 working_youth1518 working_youth1922 working_youth2325 interest_chr likely hhsize stem_f2f i.cons_quint urban status_chr)
eststo margin: margins, dydx(female i.age_group edu_aspgap working_child14 working_youth1518 working_youth1922 working_youth2325 interest_chr likely hhsize stem_f2f i.cons_quint urban status_chr) post

outreg2 using "$tables\Table 2.xls", label append ctitle(`x')

restore
}



** Table 3 Migration Aspirations by country ** 

* Ethiopia *
preserve
keep if country==1

** Migration
logit migration female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA [pw=weights], cluster(ea_id)
margins, dydx (female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA)

eststo margin: margins, dydx (female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA) post 
outreg2   using "$tables\Table 3.xls", label append ctitle(Migrate)

** Where to go?
logit s5eq37__1 female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA [pw=weights], cluster(ea_id)
margins, dydx (female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA)
eststo margin: margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA) post 
outreg2  using "$tables\Table 3.xls", label append ctitle(Moving to capital city)  

logit s5eq37__2 female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA [pw=weights], cluster(ea_id)
margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA)
eststo margin: margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA) post 
outreg2  using "$tables\Table 3.xls", label append ctitle(Moving to town/city) 

logit s5eq37__3 female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA [pw=weights], cluster(ea_id)
margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA)
eststo margin: margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA) post 
outreg2  using "$tables\Table 3.xls", label append ctitle(Moving to rural area)

logit s5eq37__4 female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA [pw=weights], cluster(ea_id)
margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA)
eststo margin: margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA) post 
outreg2  using "$tables\Table 3.xls", label append ctitle(Moving to another country) 

restore


* Malawi *
preserve
keep if country==2

** Migration
logit migration female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA [pw=weights], cluster(ea_id)
margins, dydx (female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA)

eststo margin: margins, dydx (female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA) post 
outreg2   using "$tables\Table 4.xls", label append ctitle(Migrate)

** Where to go?
logit s5eq37__1 female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA [pw=weights], cluster(ea_id)
margins, dydx (female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA)
eststo margin: margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA) post 
outreg2  using "$tables\Table 4.xls", label append ctitle(Moving to capital city)  

logit s5eq37__2 female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA [pw=weights], cluster(ea_id)
margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA)
eststo margin: margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA) post 
outreg2  using "$tables\Table 4.xls", label append ctitle(Moving to town/city) 

logit s5eq37__3 female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA [pw=weights], cluster(ea_id)
margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA)
eststo margin: margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA) post 
outreg2  using "$tables\Table 4.xls", label append ctitle(Moving to rural area)

logit s5eq37__4 female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA [pw=weights], cluster(ea_id)
margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA)
eststo margin: margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA) post 
outreg2  using "$tables\Table 4.xls", label append ctitle(Moving to another country) 

restore


* Nigeria *
preserve
keep if country==3

** Migration
logit migration female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA [pw=weights], cluster(ea_id)
margins, dydx (female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA)

eststo margin: margins, dydx (female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA) post 
outreg2   using "$tables\Table 5.xls", label append ctitle(Migrate)

** Where to go?
logit s5eq37__1 female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA [pw=weights], cluster(ea_id)
margins, dydx (female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA)
eststo margin: margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA) post 
outreg2  using "$tables\Table 5.xls", label append ctitle(Moving to capital city)  

logit s5eq37__2 female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA [pw=weights], cluster(ea_id)
margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA)
eststo margin: margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA) post 
outreg2  using "$tables\Table 5.xls", label append ctitle(Moving to town/city) 

logit s5eq37__3 female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA [pw=weights], cluster(ea_id)
margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA)
eststo margin: margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA) post 
outreg2  using "$tables\Table 5.xls", label append ctitle(Moving to rural area)

logit s5eq37__4 female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA [pw=weights], cluster(ea_id)
margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA)
eststo margin: margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA) post 
outreg2  using "$tables\Table 5.xls", label append ctitle(Moving to another country) 

restore