******************************************************************
**  Countries: Nigeria, Malawi, Ethiopia                        **
**                                                              **
**  ANNEX TABLES     											**
**                                                              **
**  Program first written: January 2022 (Valentina Costa) 		**
**  Program last revised:  September 2023 		                ** 
******************************************************************
use "$pooled.dta", clear

egen EA=group(country ea_id)


** Table A2 Summary statistics **

** UNWEIGHTED RESULTS **
putexcel set "$tables\Table A2", sheet("unweighted") modify 
putexcel B1=("Ethiopia") D1=("Malawi") F1=("Nigeria") H1=("Pooled sample")
putexcel A2=("Main variables") B2=("Freq.") C2=("Percent") D2=("Freq.") E2=("Percent") F2=("Freq.") G2=("Percent") H2=("Freq.") I2=("Percent")

putexcel A4=("Aspiration to STEM--related job") 
putexcel A6=("Aspiration to complete university degree") 
putexcel A8=("Aspiration to migrate")
 
putexcel A10=("Youth is female") 

putexcel A12=("15-18 years")  
putexcel A14=("19-22 years") 
putexcel A16=("23-25 years")
 
putexcel A18=("No degree completed") 
putexcel A20=("Primary education") 
putexcel A22=("Secondary education") 
putexcel A24=("Tertiary education")
putexcel A26=("University education")

putexcel A28=("Attending school") 
putexcel A30=("Working")
putexcel A32=("Neither studying not working (NEET)")

putexcel A34=("Doing the ideal job")
putexcel A36=("Started working <14 years")
putexcel A38=("Started working 15-18 years")
putexcel A40=("Started working 19-22 years")
putexcel A42=("Started working 23-25 years")

putexcel A44=("Quintile 1(poorest)") 
putexcel A46=("Quintile 2") 
putexcel A48=("Quintile 3") 
putexcel A50=("Quintile 4") 
putexcel A52=("Quintile 5(richest)") 

putexcel A54=("Urban") 
putexcel A56=("Job that family and friends regard highly") 
putexcel A58=("Interesting job to do")  
putexcel A60=("Youth knows someone in the community that has your dream job") 
putexcel A62=("Youth likelihood to reach the dream job (self-efficacy)")
putexcel A64=("HHs with remittances from family within the country") 
putexcel A66=("HHs with remittances from abroad")


* ETHIOPIA *

preserve 
keep if country==1

foreach x in stem_job ideal_uniabove migration female age_group1518 age_group1922 age_group2325 none primary secondary tertiary university attending_schoolt working  neitherw_s working_child14 working_youth1518 working_youth1922 working_youth2325 cons_quint1 cons_quint2 cons_quint3 cons_quint4 cons_quint5 urban status_chr interest_chr role_model likely remittance1 remittance2 {
tabulate `x', matcell(freq`x') matrow(names`x')
matrix list freq`x'
matrix list names`x' 
}

putexcel B3= matrix(freqstem_job) C3=matrix(freqstem_job/r(N))
putexcel B5=matrix(freqideal_uniabove) C5=matrix(freqideal_uniabove/r(N))
putexcel B7=matrix(freqmigration) C7=matrix(freqmigration/r(N))

putexcel B9=matrix(freqfemale) C9=matrix(freqfemale/r(N))

putexcel B11=matrix(freqage_group1518) C11=matrix(freqage_group1518/r(N))
putexcel B13=matrix(freqage_group1922) C13=matrix(freqage_group1922/r(N))
putexcel B15=matrix(freqage_group2325) C15=matrix(freqage_group2325/r(N))

putexcel B17=matrix(freqnone) C17=matrix(freqnone/r(N))
putexcel B19=matrix(freqprimary) C19=matrix(freqprimary/r(N))
putexcel B21=matrix(freqsecondary) C21=matrix(freqsecondary/r(N))
putexcel B23=matrix(freqtertiary) C23=matrix(freqtertiary/r(N))
putexcel B25=matrix(frequniversity) C25=matrix(frequniversity/r(N))

putexcel B27=matrix(freqattending_schoolt) C27=matrix(freqattending_schoolt/r(N))
putexcel B29=matrix(freqworking) C29=matrix(freqworking/r(N))
putexcel B31=matrix(freqneitherw_s) C31=matrix(freqneitherw_s/r(N))

putexcel B35=matrix(freqworking_child14) C35=matrix(freqworking_child14/r(N))
putexcel B37=matrix(freqworking_youth1518) C37=matrix(freqworking_youth1518/r(N))
putexcel B39=matrix(freqworking_youth1922) C39=matrix(freqworking_youth1922/r(N))
putexcel B41=matrix(freqworking_youth2325) C41=matrix(freqworking_youth2325/r(N))

putexcel B43=matrix(freqcons_quint1) C43=matrix(freqcons_quint1/r(N))
putexcel B45=matrix(freqcons_quint2) C45=matrix(freqcons_quint2/r(N))
putexcel B47=matrix(freqcons_quint3) C47=matrix(freqcons_quint3/r(N))
putexcel B49=matrix(freqcons_quint4) C49=matrix(freqcons_quint4/r(N))
putexcel B51=matrix(freqcons_quint5) C51=matrix(freqcons_quint5/r(N))

putexcel B53=matrix(frequrban) C53=matrix(frequrban/r(N))
putexcel B55=matrix(freqstatus_chr) C55=matrix(freqstatus_chr/r(N))
putexcel B57=matrix(freqinterest_chr) C57=matrix(freqinterest_chr/r(N))

putexcel B59=matrix(freqrole_model) C59=matrix(freqrole_model/r(N))
putexcel B61=matrix(freqlikely) C61=matrix(freqlikely/r(N))
putexcel B63=matrix(freqremittance1) C63=matrix(freqremittance1/r(N))
putexcel B65=matrix(freqremittance2) C65=matrix(freqremittance2/r(N))


* sub-sample of youths who work *
keep if working==1
foreach x in ideal_job_curr  {
tabulate `x', matcell(freq`x') matrow(names`x')
matrix list freq`x'
matrix list names`x' 
}

putexcel B33=matrix(freqideal_job_curr) C33=matrix(freqideal_job_curr/r(N))

restore


* MALAWI *

preserve 
keep if country==2

foreach x in stem_job ideal_uniabove migration female age_group1518 age_group1922 age_group2325 none primary secondary tertiary university attending_schoolt working neitherw_s working_child14 working_youth1518 working_youth1922 working_youth2325 cons_quint1 cons_quint2 cons_quint3 cons_quint4 cons_quint5 urban status_chr interest_chr role_model likely remittance1 remittance2 {
tabulate `x', matcell(freq`x') matrow(names`x')
matrix list freq`x'
matrix list names`x' 
}

putexcel D3= matrix(freqstem_job) E3=matrix(freqstem_job/r(N))
putexcel D5=matrix(freqideal_uniabove) E5=matrix(freqideal_uniabove/r(N))
putexcel D7=matrix(freqmigration) E7=matrix(freqmigration/r(N))

putexcel D9=matrix(freqfemale) E9=matrix(freqfemale/r(N))
putexcel D11=matrix(freqage_group1518) E11=matrix(freqage_group1518/r(N))
putexcel D13=matrix(freqage_group1922) E13=matrix(freqage_group1922/r(N))
putexcel D15=matrix(freqage_group2325) E15=matrix(freqage_group2325/r(N))

putexcel D17=matrix(freqnone) E17=matrix(freqnone/r(N))
putexcel D19=matrix(freqprimary) E19=matrix(freqprimary/r(N))
putexcel D21=matrix(freqsecondary) E21=matrix(freqsecondary/r(N))
putexcel D23=matrix(freqtertiary) E23=matrix(freqtertiary/r(N))
putexcel D25=matrix(frequniversity) E25=matrix(frequniversity/r(N))

putexcel D27=matrix(freqattending_schoolt) E27=matrix(freqattending_schoolt/r(N))
putexcel D29=matrix(freqworking) E29=matrix(freqworking/r(N))
putexcel D31=matrix(freqneitherw_s) E31=matrix(freqneitherw_s/r(N))

putexcel D35=matrix(freqworking_child14) E35=matrix(freqworking_child14/r(N))
putexcel D37=matrix(freqworking_youth1518) E37=matrix(freqworking_youth1518/r(N))
putexcel D39=matrix(freqworking_youth1922) E39=matrix(freqworking_youth1922/r(N))
putexcel D41=matrix(freqworking_youth2325) E41=matrix(freqworking_youth2325/r(N))

putexcel D43=matrix(freqcons_quint1) E43=matrix(freqcons_quint1/r(N))
putexcel D45=matrix(freqcons_quint2) E45=matrix(freqcons_quint2/r(N))
putexcel D47=matrix(freqcons_quint3) E47=matrix(freqcons_quint3/r(N))
putexcel D49=matrix(freqcons_quint4) E49=matrix(freqcons_quint4/r(N))
putexcel D51=matrix(freqcons_quint5) E51=matrix(freqcons_quint5/r(N))

putexcel D53=matrix(frequrban) E53=matrix(frequrban/r(N))
putexcel D55=matrix(freqstatus_chr) E55=matrix(freqstatus_chr/r(N))
putexcel D57=matrix(freqinterest_chr) E57=matrix(freqinterest_chr/r(N))

putexcel D59=matrix(freqrole_model) E59=matrix(freqrole_model/r(N))
putexcel D61=matrix(freqlikely) E61=matrix(freqlikely/r(N))
putexcel D63=matrix(freqremittance1) E63=matrix(freqremittance1/r(N))
putexcel D65=matrix(freqremittance2) E65=matrix(freqremittance2/r(N))


* sub-sample of youths who work *
keep if working==1
foreach x in ideal_job_curr {
tabulate `x', matcell(freq`x') matrow(names`x')
matrix list freq`x'
matrix list names`x' 
}

putexcel D33=matrix(freqideal_job_curr) E33=matrix(freqideal_job_curr/r(N))

restore


* NIGERIA *
preserve 
keep if country==3

foreach x in stem_job ideal_uniabove migration female age_group1518 age_group1922 age_group2325 none primary secondary tertiary university attending_schoolt working neitherw_s working_child14 working_youth1518 working_youth1922 working_youth2325 cons_quint1 cons_quint2 cons_quint3 cons_quint4 cons_quint5 urban status_chr interest_chr role_model likely remittance1 remittance2 {
tabulate `x', matcell(freq`x') matrow(names`x')
matrix list freq`x'
matrix list names`x' 
}

putexcel F3= matrix(freqstem_job) G3=matrix(freqstem_job/r(N))
putexcel F5=matrix(freqideal_uniabove) G5=matrix(freqideal_uniabove/r(N))
putexcel F7=matrix(freqmigration) G7=matrix(freqmigration/r(N))

putexcel F9=matrix(freqfemale) G9=matrix(freqfemale/r(N))
putexcel F11=matrix(freqage_group1518) G11=matrix(freqage_group1518/r(N))
putexcel F13=matrix(freqage_group1922) G13=matrix(freqage_group1922/r(N))
putexcel F15=matrix(freqage_group2325) G15=matrix(freqage_group2325/r(N))

putexcel F17=matrix(freqnone) G17=matrix(freqnone/r(N))
putexcel F19=matrix(freqprimary) G19=matrix(freqprimary/r(N))
putexcel F21=matrix(freqsecondary) G21=matrix(freqsecondary/r(N))
putexcel F23=matrix(freqtertiary) G23=matrix(freqtertiary/r(N))
putexcel F25=matrix(frequniversity) G25=matrix(frequniversity/r(N))

putexcel F27=matrix(freqattending_schoolt) G27=matrix(freqattending_schoolt/r(N))
putexcel F29=matrix(freqworking) G29=matrix(freqworking/r(N))
putexcel F31=matrix(freqneitherw_s) G31=matrix(freqneitherw_s/r(N))

putexcel F35=matrix(freqworking_child14) G35=matrix(freqworking_child14/r(N))
putexcel F37=matrix(freqworking_youth1518) G37=matrix(freqworking_youth1518/r(N))
putexcel F39=matrix(freqworking_youth1922) G39=matrix(freqworking_youth1922/r(N))
putexcel F41=matrix(freqworking_youth2325) G41=matrix(freqworking_youth2325/r(N))

putexcel F43=matrix(freqcons_quint1) G43=matrix(freqcons_quint1/r(N))
putexcel F45=matrix(freqcons_quint2) G45=matrix(freqcons_quint2/r(N))
putexcel F47=matrix(freqcons_quint3) G47=matrix(freqcons_quint3/r(N))
putexcel F49=matrix(freqcons_quint4) G49=matrix(freqcons_quint4/r(N))
putexcel F51=matrix(freqcons_quint5) G51=matrix(freqcons_quint5/r(N))

putexcel F53=matrix(frequrban) G53=matrix(frequrban/r(N))
putexcel F55=matrix(freqstatus_chr) G55=matrix(freqstatus_chr/r(N))
putexcel F57=matrix(freqinterest_chr) G57=matrix(freqinterest_chr/r(N))

putexcel F59=matrix(freqrole_model) G59=matrix(freqrole_model/r(N))
putexcel F61=matrix(freqlikely) G61=matrix(freqlikely/r(N))
putexcel F63=matrix(freqremittance1) G63=matrix(freqremittance1/r(N))
putexcel F65=matrix(freqremittance2) G65=matrix(freqremittance2/r(N))


* sub-sample of youths who work *
keep if working==1
foreach x in ideal_job_curr {
tabulate `x', matcell(freq`x') matrow(names`x')
matrix list freq`x'
matrix list names`x' 
}

putexcel F33=matrix(freqideal_job_curr) G33=matrix(freqideal_job_curr/r(N))

restore


* POOLED SAMPLE *
foreach x in stem_job ideal_uniabove migration female age_group1518 age_group1922 age_group2325 none primary secondary tertiary university attending_schoolt working neitherw_s working_child14 working_youth1518 working_youth1922 working_youth2325 cons_quint1 cons_quint2 cons_quint3 cons_quint4 cons_quint5 urban status_chr interest_chr role_model likely remittance1 remittance2 {
tabulate `x', matcell(freq`x') matrow(names`x')
matrix list freq`x'
matrix list names`x' 
}

putexcel H3= matrix(freqstem_job) I3=matrix(freqstem_job/r(N))
putexcel H5=matrix(freqideal_uniabove) I5=matrix(freqideal_uniabove/r(N))
putexcel H7=matrix(freqmigration) I7=matrix(freqmigration/r(N))

putexcel H9=matrix(freqfemale) I9=matrix(freqfemale/r(N))
putexcel H11=matrix(freqage_group1518) I11=matrix(freqage_group1518/r(N))
putexcel H13=matrix(freqage_group1922) I13=matrix(freqage_group1922/r(N))
putexcel H15=matrix(freqage_group2325) I15=matrix(freqage_group2325/r(N))

putexcel H17=matrix(freqnone) I17=matrix(freqnone/r(N))
putexcel H19=matrix(freqprimary) I19=matrix(freqprimary/r(N))
putexcel H21=matrix(freqsecondary) I21=matrix(freqsecondary/r(N))
putexcel H23=matrix(freqtertiary) I23=matrix(freqtertiary/r(N))
putexcel H25=matrix(frequniversity) I25=matrix(frequniversity/r(N))

putexcel H27=matrix(freqattending_schoolt) I27=matrix(freqattending_schoolt/r(N))
putexcel H29=matrix(freqworking) I29=matrix(freqworking/r(N))
putexcel H31=matrix(freqneitherw_s) I31=matrix(freqneitherw_s/r(N))

putexcel H35=matrix(freqworking_child14) I35=matrix(freqworking_child14/r(N))
putexcel H37=matrix(freqworking_youth1518) I37=matrix(freqworking_youth1518/r(N))
putexcel H39=matrix(freqworking_youth1922) I39=matrix(freqworking_youth1922/r(N))
putexcel H41=matrix(freqworking_youth2325) I41=matrix(freqworking_youth2325/r(N))

putexcel H43=matrix(freqcons_quint1) I43=matrix(freqcons_quint1/r(N))
putexcel H45=matrix(freqcons_quint2) I45=matrix(freqcons_quint2/r(N))
putexcel H47=matrix(freqcons_quint3) I47=matrix(freqcons_quint3/r(N))
putexcel H49=matrix(freqcons_quint4) I49=matrix(freqcons_quint4/r(N))
putexcel H51=matrix(freqcons_quint5) I51=matrix(freqcons_quint5/r(N))

putexcel H53=matrix(frequrban) I53=matrix(frequrban/r(N))
putexcel H55=matrix(freqstatus_chr) I55=matrix(freqstatus_chr/r(N))
putexcel H57=matrix(freqinterest_chr) I57=matrix(freqinterest_chr/r(N))

putexcel H59=matrix(freqrole_model) I59=matrix(freqrole_model/r(N))
putexcel H61=matrix(freqlikely) I61=matrix(freqlikely/r(N))
putexcel H63=matrix(freqremittance1) I63=matrix(freqremittance1/r(N))
putexcel H65=matrix(freqremittance2) I65=matrix(freqremittance2/r(N))


* sub-sample of youths who work *
preserve
keep if working==1
foreach x in ideal_job_curr {
tabulate `x', matcell(freq`x') matrow(names`x')
matrix list freq`x'
matrix list names`x' 
}

putexcel H33=matrix(freqideal_job_curr) I33=matrix(freqideal_job_curr/r(N))
restore


** WEIGHTED RESULTS **

putexcel set "$tables\Table A2", sheet("weighted") modify 
putexcel B1=("Ethiopia") D1=("Malawi") F1=("Nigeria") H1=("Pooled sample")
putexcel A2=("Main variables") B2=("Freq.") C2=("Percent") D2=("Freq.") E2=("Percent") F2=("Freq.") G2=("Percent") H2=("Freq.") I2=("Percent")

putexcel A4=("Aspiration to STEM--related job") 
putexcel A6=("Aspiration to complete university degree") 
putexcel A8=("Aspiration to migrate")
 
putexcel A10=("Youth is female") 

putexcel A12=("15-18 years")  
putexcel A14=("19-22 years") 
putexcel A16=("23-25 years")
 
putexcel A18=("No degree completed") 
putexcel A20=("Primary education") 
putexcel A22=("Secondary education") 
putexcel A24=("Tertiary education")
putexcel A26=("University education")

putexcel A28=("Attending school") 
putexcel A30=("Working")
putexcel A32=("Neither studying not working (NEET)")

putexcel A34=("Doing the ideal job")
putexcel A36=("Started working <14 years")
putexcel A38=("Started working 15-18 years")
putexcel A40=("Started working 19-22 years")
putexcel A42=("Started working 23-25 years")

putexcel A44=("Quintile 1(poorest)") 
putexcel A46=("Quintile 2") 
putexcel A48=("Quintile 3") 
putexcel A50=("Quintile 4") 
putexcel A52=("Quintile 5(richest)") 

putexcel A54=("Urban") 
putexcel A56=("Job that family and friends regard highly") 
putexcel A58=("Interesting job to do")  
putexcel A60=("Youth knows someone in the community that has your dream job") 
putexcel A62=("Youth likelihood to reach the dream job (self-efficacy)")
putexcel A64=("HHs with remittances from family within the country") 
putexcel A66=("HHs with remittances from abroad")


* ETHIOPIA *
preserve 
keep if country==1

gen obs=_N
sum obs [aw=weights] // unweighted=881, weighted=2651530.38

foreach x in stem_job ideal_uniabove migration female age_group1518 age_group1922 age_group2325 none primary secondary tertiary university attending_schoolt working neitherw_s working_child14 working_youth1518 working_youth1922 working_youth2325 cons_quint1 cons_quint2 cons_quint3 cons_quint4 cons_quint5 urban status_chr interest_chr role_model likely remittance1 remittance2 {
tabulate `x' [aw=weights], matcell(freq`x') matrow(names`x') 
matrix list freq`x'
matrix list names`x' 
}

putexcel B3= matrix(freqstem_job) C3=matrix(freqstem_job/r(N))
putexcel B5=matrix(freqideal_uniabove) C5=matrix(freqideal_uniabove/r(N))
putexcel B7=matrix(freqmigration) C7=matrix(freqmigration/r(N))

putexcel B9=matrix(freqfemale) C9=matrix(freqfemale/r(N))

putexcel B11=matrix(freqage_group1518) C11=matrix(freqage_group1518/r(N))
putexcel B13=matrix(freqage_group1922) C13=matrix(freqage_group1922/r(N))
putexcel B15=matrix(freqage_group2325) C15=matrix(freqage_group2325/r(N))

putexcel B17=matrix(freqnone) C17=matrix(freqnone/r(N))
putexcel B19=matrix(freqprimary) C19=matrix(freqprimary/r(N))
putexcel B21=matrix(freqsecondary) C21=matrix(freqsecondary/r(N))
putexcel B23=matrix(freqtertiary) C23=matrix(freqtertiary/r(N))
putexcel B25=matrix(frequniversity) C25=matrix(frequniversity/r(N))

putexcel B27=matrix(freqattending_schoolt) C27=matrix(freqattending_schoolt/r(N))
putexcel B29=matrix(freqworking) C29=matrix(freqworking/r(N))
putexcel B31=matrix(freqneitherw_s) C31=matrix(freqneitherw_s/r(N))

putexcel B35=matrix(freqworking_child14) C35=matrix(freqworking_child14/r(N))
putexcel B37=matrix(freqworking_youth1518) C37=matrix(freqworking_youth1518/r(N))
putexcel B39=matrix(freqworking_youth1922) C39=matrix(freqworking_youth1922/r(N))
putexcel B41=matrix(freqworking_youth2325) C41=matrix(freqworking_youth2325/r(N))

putexcel B43=matrix(freqcons_quint1) C43=matrix(freqcons_quint1/r(N))
putexcel B45=matrix(freqcons_quint2) C45=matrix(freqcons_quint2/r(N))
putexcel B47=matrix(freqcons_quint3) C47=matrix(freqcons_quint3/r(N))
putexcel B49=matrix(freqcons_quint4) C49=matrix(freqcons_quint4/r(N))
putexcel B51=matrix(freqcons_quint5) C51=matrix(freqcons_quint5/r(N))

putexcel B53=matrix(frequrban) C53=matrix(frequrban/r(N))
putexcel B55=matrix(freqstatus_chr) C55=matrix(freqstatus_chr/r(N))
putexcel B57=matrix(freqinterest_chr) C57=matrix(freqinterest_chr/r(N))

putexcel B59=matrix(freqrole_model) C59=matrix(freqrole_model/r(N))
putexcel B61=matrix(freqlikely) C61=matrix(freqlikely/r(N))
putexcel B63=matrix(freqremittance1) C63=matrix(freqremittance1/r(N))
putexcel B65=matrix(freqremittance2) C65=matrix(freqremittance2/r(N))


* sub-sample of youths who work *
keep if working==1
foreach x in ideal_job_curr {
tabulate `x' [aw=weights], matcell(freq`x') matrow(names`x')
matrix list freq`x'
matrix list names`x' 
}

putexcel B33=matrix(freqideal_job_curr) C33=matrix(freqideal_job_curr/r(N))


restore


* MALAWI *
preserve 
keep if country==2

gen obs=_N
sum obs [aw=weights] // unweighted=873, weighted=1803205.14

foreach x in stem_job ideal_uniabove migration female age_group1518 age_group1922 age_group2325 none primary secondary tertiary university attending_schoolt working neitherw_s working_child14 working_youth1518 working_youth1922 working_youth2325 cons_quint1 cons_quint2 cons_quint3 cons_quint4 cons_quint5 urban status_chr interest_chr role_model likely remittance1 remittance2 {
tabulate `x' [aw=weights], matcell(freq`x') matrow(names`x')
matrix list freq`x'
matrix list names`x' 
}

putexcel D3= matrix(freqstem_job) E3=matrix(freqstem_job/r(N))
putexcel D5=matrix(freqideal_uniabove) E5=matrix(freqideal_uniabove/r(N))
putexcel D7=matrix(freqmigration) E7=matrix(freqmigration/r(N))

putexcel D9=matrix(freqfemale) E9=matrix(freqfemale/r(N))
putexcel D11=matrix(freqage_group1518) E11=matrix(freqage_group1518/r(N))
putexcel D13=matrix(freqage_group1922) E13=matrix(freqage_group1922/r(N))
putexcel D15=matrix(freqage_group2325) E15=matrix(freqage_group2325/r(N))

putexcel D17=matrix(freqnone) E17=matrix(freqnone/r(N))
putexcel D19=matrix(freqprimary) E19=matrix(freqprimary/r(N))
putexcel D21=matrix(freqsecondary) E21=matrix(freqsecondary/r(N))
putexcel D23=matrix(freqtertiary) E23=matrix(freqtertiary/r(N))
putexcel D25=matrix(frequniversity) E25=matrix(frequniversity/r(N))

putexcel D27=matrix(freqattending_schoolt) E27=matrix(freqattending_schoolt/r(N))
putexcel D29=matrix(freqworking) E29=matrix(freqworking/r(N))
putexcel D31=matrix(freqneitherw_s) E31=matrix(freqneitherw_s/r(N))

putexcel D35=matrix(freqworking_child14) E35=matrix(freqworking_child14/r(N))
putexcel D37=matrix(freqworking_youth1518) E37=matrix(freqworking_youth1518/r(N))
putexcel D39=matrix(freqworking_youth1922) E39=matrix(freqworking_youth1922/r(N))
putexcel D41=matrix(freqworking_youth2325) E41=matrix(freqworking_youth2325/r(N))

putexcel D43=matrix(freqcons_quint1) E43=matrix(freqcons_quint1/r(N))
putexcel D45=matrix(freqcons_quint2) E45=matrix(freqcons_quint2/r(N))
putexcel D47=matrix(freqcons_quint3) E47=matrix(freqcons_quint3/r(N))
putexcel D49=matrix(freqcons_quint4) E49=matrix(freqcons_quint4/r(N))
putexcel D51=matrix(freqcons_quint5) E51=matrix(freqcons_quint5/r(N))

putexcel D53=matrix(frequrban) E53=matrix(frequrban/r(N))
putexcel D55=matrix(freqstatus_chr) E55=matrix(freqstatus_chr/r(N))
putexcel D57=matrix(freqinterest_chr) E57=matrix(freqinterest_chr/r(N))

putexcel D59=matrix(freqrole_model) E59=matrix(freqrole_model/r(N))
putexcel D61=matrix(freqlikely) E61=matrix(freqlikely/r(N))
putexcel D63=matrix(freqremittance1) E63=matrix(freqremittance1/r(N))
putexcel D65=matrix(freqremittance2) E65=matrix(freqremittance2/r(N))


* sub-sample of youths who work *
keep if working==1
foreach x in ideal_job_curr {
tabulate `x'[aw=weights], matcell(freq`x') matrow(names`x')
matrix list freq`x'
matrix list names`x' 
}

putexcel D33=matrix(freqideal_job_curr) E33=matrix(freqideal_job_curr/r(N))

restore


* NIGERIA *
preserve 
keep if country==3

gen obs=_N
sum obs [aw=weights] // unweighted=934, weighted=5029489.78

foreach x in stem_job ideal_uniabove migration female age_group1518 age_group1922 age_group2325 none primary secondary tertiary university attending_schoolt working neitherw_s working_child14 working_youth1518 working_youth1922 working_youth2325 cons_quint1 cons_quint2 cons_quint3 cons_quint4 cons_quint5 urban status_chr interest_chr role_model likely remittance1 remittance2 {
tabulate `x' [aw=weights], matcell(freq`x') matrow(names`x')
matrix list freq`x'
matrix list names`x' 
}

putexcel F3= matrix(freqstem_job) G3=matrix(freqstem_job/r(N))
putexcel F5=matrix(freqideal_uniabove) G5=matrix(freqideal_uniabove/r(N))
putexcel F7=matrix(freqmigration) G7=matrix(freqmigration/r(N))

putexcel F9=matrix(freqfemale) G9=matrix(freqfemale/r(N))
putexcel F11=matrix(freqage_group1518) G11=matrix(freqage_group1518/r(N))
putexcel F13=matrix(freqage_group1922) G13=matrix(freqage_group1922/r(N))
putexcel F15=matrix(freqage_group2325) G15=matrix(freqage_group2325/r(N))

putexcel F17=matrix(freqnone) G17=matrix(freqnone/r(N))
putexcel F19=matrix(freqprimary) G19=matrix(freqprimary/r(N))
putexcel F21=matrix(freqsecondary) G21=matrix(freqsecondary/r(N))
putexcel F23=matrix(freqtertiary) G23=matrix(freqtertiary/r(N))
putexcel F25=matrix(frequniversity) G25=matrix(frequniversity/r(N))

putexcel F27=matrix(freqattending_schoolt) G27=matrix(freqattending_schoolt/r(N))
putexcel F29=matrix(freqworking) G29=matrix(freqworking/r(N))
putexcel F31=matrix(freqneitherw_s) G31=matrix(freqneitherw_s/r(N))

putexcel F35=matrix(freqworking_child14) G35=matrix(freqworking_child14/r(N))
putexcel F37=matrix(freqworking_youth1518) G37=matrix(freqworking_youth1518/r(N))
putexcel F39=matrix(freqworking_youth1922) G39=matrix(freqworking_youth1922/r(N))
putexcel F41=matrix(freqworking_youth2325) G41=matrix(freqworking_youth2325/r(N))

putexcel F43=matrix(freqcons_quint1) G43=matrix(freqcons_quint1/r(N))
putexcel F45=matrix(freqcons_quint2) G45=matrix(freqcons_quint2/r(N))
putexcel F47=matrix(freqcons_quint3) G47=matrix(freqcons_quint3/r(N))
putexcel F49=matrix(freqcons_quint4) G49=matrix(freqcons_quint4/r(N))
putexcel F51=matrix(freqcons_quint5) G51=matrix(freqcons_quint5/r(N))

putexcel F53=matrix(frequrban) G53=matrix(frequrban/r(N))
putexcel F55=matrix(freqstatus_chr) G55=matrix(freqstatus_chr/r(N))
putexcel F57=matrix(freqinterest_chr) G57=matrix(freqinterest_chr/r(N))

putexcel F59=matrix(freqrole_model) G59=matrix(freqrole_model/r(N))
putexcel F61=matrix(freqlikely) G61=matrix(freqlikely/r(N))
putexcel F63=matrix(freqremittance1) G63=matrix(freqremittance1/r(N))
putexcel F65=matrix(freqremittance2) G65=matrix(freqremittance2/r(N))


* sub-sample of youths who work *
keep if working==1
foreach x in ideal_job_curr {
tabulate `x'[aw=weights], matcell(freq`x') matrow(names`x')
matrix list freq`x'
matrix list names`x' 
}

putexcel F33=matrix(freqideal_job_curr) G33=matrix(freqideal_job_curr/r(N))

restore


* POOLED SAMPLE *

gen obs=_N
sum obs [aw=weights]   // unweighted=2,688, weighted=9484225.3

foreach x in stem_job ideal_uniabove migration female age_group1518 age_group1922 age_group2325 none primary secondary tertiary university attending_schoolt working neitherw_s working_child14 working_youth1518 working_youth1922 working_youth2325 cons_quint1 cons_quint2 cons_quint3 cons_quint4 cons_quint5 urban status_chr interest_chr role_model likely remittance1 remittance2 {
tabulate `x' [aw=weights], matcell(freq`x') matrow(names`x')
matrix list freq`x'
matrix list names`x' 
}

putexcel H3= matrix(freqstem_job) I3=matrix(freqstem_job/r(N))
putexcel H5=matrix(freqideal_uniabove) I5=matrix(freqideal_uniabove/r(N))
putexcel H7=matrix(freqmigration) I7=matrix(freqmigration/r(N))

putexcel H9=matrix(freqfemale) I9=matrix(freqfemale/r(N))
putexcel H11=matrix(freqage_group1518) I11=matrix(freqage_group1518/r(N))
putexcel H13=matrix(freqage_group1922) I13=matrix(freqage_group1922/r(N))
putexcel H15=matrix(freqage_group2325) I15=matrix(freqage_group2325/r(N))

putexcel H17=matrix(freqnone) I17=matrix(freqnone/r(N))
putexcel H19=matrix(freqprimary) I19=matrix(freqprimary/r(N))
putexcel H21=matrix(freqsecondary) I21=matrix(freqsecondary/r(N))
putexcel H23=matrix(freqtertiary) I23=matrix(freqtertiary/r(N))
putexcel H25=matrix(frequniversity) I25=matrix(frequniversity/r(N))

putexcel H27=matrix(freqattending_schoolt) I27=matrix(freqattending_schoolt/r(N))
putexcel H29=matrix(freqworking) I29=matrix(freqworking/r(N))
putexcel H31=matrix(freqneitherw_s) I31=matrix(freqneitherw_s/r(N))

putexcel H35=matrix(freqworking_child14) I35=matrix(freqworking_child14/r(N))
putexcel H37=matrix(freqworking_youth1518) I37=matrix(freqworking_youth1518/r(N))
putexcel H39=matrix(freqworking_youth1922) I39=matrix(freqworking_youth1922/r(N))
putexcel H41=matrix(freqworking_youth2325) I41=matrix(freqworking_youth2325/r(N))

putexcel H43=matrix(freqcons_quint1) I43=matrix(freqcons_quint1/r(N))
putexcel H45=matrix(freqcons_quint2) I45=matrix(freqcons_quint2/r(N))
putexcel H47=matrix(freqcons_quint3) I47=matrix(freqcons_quint3/r(N))
putexcel H49=matrix(freqcons_quint4) I49=matrix(freqcons_quint4/r(N))
putexcel H51=matrix(freqcons_quint5) I51=matrix(freqcons_quint5/r(N))

putexcel H53=matrix(frequrban) I53=matrix(frequrban/r(N))
putexcel H55=matrix(freqstatus_chr) I55=matrix(freqstatus_chr/r(N))
putexcel H57=matrix(freqinterest_chr) I57=matrix(freqinterest_chr/r(N))

putexcel H59=matrix(freqrole_model) I59=matrix(freqrole_model/r(N))
putexcel H61=matrix(freqlikely) I61=matrix(freqlikely/r(N))
putexcel H63=matrix(freqremittance1) I63=matrix(freqremittance1/r(N))
putexcel H65=matrix(freqremittance2) I65=matrix(freqremittance2/r(N))


* sub-sample of youths who work *
preserve
keep if working==1
foreach x in ideal_job_curr {
tabulate `x' [aw=weights], matcell(freq`x') matrow(names`x')
matrix list freq`x'
matrix list names`x' 
}

putexcel H33=matrix(freqideal_job_curr) I33=matrix(freqideal_job_curr/r(N))
restore




**************
** Table A3. Migrations Aspirations (pooled sample) **

** Migration
logit migration female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA [pw=weights], cluster(EA)
margins, dydx (female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA)
eststo margin: margins, dydx (female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA) post 
outreg2  using "$tables\Table A3.xls", label append ctitle(Migrate)

** Where to go?
logit s5eq37__1 female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA [pw=weights], cluster(EA)
margins, dydx (female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA)
eststo margin: margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA) post 
outreg2  using "$tables\Table A3.xls", label append ctitle(Moving to capital city)

logit s5eq37__2 female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA [pw=weights], cluster(EA)
margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA)
eststo margin: margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA) post 
outreg2  using "$tables\Table A3.xls", label append ctitle(Moving to town/city)

logit s5eq37__3 female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA [pw=weights], cluster(EA)
margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA)
eststo margin: margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA) post 
outreg2  using "$tables\Table A3.xls", label append ctitle(Moving to rural area)

logit s5eq37__4 female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA [pw=weights], cluster(EA)
margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA)
eststo margin: margins, dydx ( female i.age_group edu_youth_yrs working neitherw_s ideal_job_curr role_model interest_chr lack_money stem_job status_chr urban i.cons_quint  eduyrs_adult_f2f wage_work_f2f ag_work_f2f own_work_f2f remittance1 remittance2 remittance1_EA remittance2_EA) post 
outreg2  using "$tables\Table A3.xls", label append ctitle(Moving to another country) 